#### Manuscript: OIK-10433
#### Title: Risk response towards roads is consistent across multiple species
##          in a temperate forest ecosystem
#### Date (creation): 11/2023
#### Date (last update): 01/2024
#### Purpose: Perform statistics of animals' steps (Supporting information 4)


#### Load packages ####

library(dplyr)
library(lubridate)
library(purrr)
library(ggplot2)
library(ggpubr)
library(sjPlot)


#### Load functions####

## Function to calculate standard error
std <- function(x) sd(x)/sqrt(length(x)) 

## Function to plot steps statistics
PlotStats <- function(data, var_dens=NULL, var_prop=NULL, var2=NULL, sex=FALSE) {
  
  ## change sex, crossings time of day and season names for clearer labelling 
  data <- data %>% mutate(sex = ifelse(sex=="f", "Females", "Males"),
                          crossings = ifelse(crossings==0, "no", "yes"),
                          tod_suncalc_end = ifelse(tod_suncalc_end=="day", "Day",
                                                   ifelse(tod_suncalc_end=="night", "Night", "Twilight")) %>% 
                            factor(),
                          night_suncalc_end = ifelse(night_suncalc_end==0, "Day", "Night") %>% 
                            factor(),
                          hour=hour(t2_),
                          season_end = ifelse(season_end==0, "Winter", "Summer"))
  
  ## vector with tidier names for axis labels
  var_nice <- c(
    "sl_" = "Step lenght [m]", "ta_" = "Turning angle",
    "dist_road_end_orig" = "Distance to Road [m]",
    "crossings" = "Road Crossing",
    "cover_end_orig" = "Canopy Cover [%]",
    "understory_end_orig" = "Understorey [%]",
    "ruggedness_end_orig" ="Ruggedness",
    "tod_suncalc_end" = "Time of day",
    "night_suncalc_end" = "Time of Day",
    "hour" = "Hour",
    "season_end" = "Season")
  
  #### Density plots
  
  ## Not grouped
  if (is.null(var_prop) & is.null(var2)) {
    plot <- map(var_dens, function(X)
      ggplot(data = data, aes(x = data[,X], fill = case_)) + 
        #geom_histogram() +
        geom_density(alpha=0.6) +
        scale_fill_brewer(palette = "Paired", name="case_", 
                          breaks=c("FALSE", "TRUE"), labels=c("Available", "Used")) +
        labs(x = var_nice[X], y = "Density", fill = "case_", title=unique(data[, "name"])) +
        theme_light() +
        theme(legend.title = element_blank(),
              panel.grid.minor = element_blank(),
              text = element_text(size=15)))
    
    ## Grouped
  } else if (is.null(var_prop) & !is.null(var2)) {
    
    plot <- map(var_dens, function(X)
      ggplot(data = data, aes(x = data[,X], fill = case_)) + 
        #geom_histogram() +
        geom_density(alpha=0.6) +
        scale_fill_brewer(palette = "Paired", name="case_", 
                          breaks=c("FALSE", "TRUE"), labels=c("Available", "Used")) +
        labs(x = var_nice[X], y = "Density", fill = "case_", title=unique(data[, "name"])) +
        theme_light() +
        theme(legend.title = element_blank(),
              panel.grid.minor = element_blank(),
              text = element_text(size=15)) +
        facet_grid(. ~ data[,var2]))
    
    #### Proportion plots
    
    ## Not grouped
  } else if (!is.null(var_prop) & is.null(var2)) {
    
    if(sex==FALSE){
      plot <- map(var_prop, function(X)
        data %>% group_by(case_, group=data[,X]) %>% summarize(n = n()) %>% 
          mutate(prop = n / sum(n), 
                 label = paste0(round(prop * 100, 1), "%")) %>% 
          ggplot(aes(factor(group), prop, fill = case_, group=case_, label = label)) + 
          geom_col(position = position_dodge2()) +
          geom_text(size = 3, vjust = -0.25, position = position_dodge(width = 1)) +
          labs(x = var_nice[X], y = "Proportion", fill = "case_", title=unique(data[, "name"])) +
          scale_fill_brewer(palette = "Paired", name="case_", 
                            breaks=c("FALSE", "TRUE"), labels=c("Available", "Used")) +
          theme_light() +
          theme(legend.title = element_blank(),
                panel.grid.minor = element_blank(),
                text = element_text(size=15)))
      
    } else if(sex==TRUE){
      
      plot <- map(var_prop, function(X)
        data %>% group_by(sex, case_, group=data[,X]) %>% summarize(n = n()) %>% 
          mutate(prop = n / sum(n), 
                 label = paste0(round(prop * 100, 1), "%")) %>% 
          ggplot(aes(factor(group), prop, fill = case_, group=case_, label = label)) + 
          geom_col(position = position_dodge2()) +
          geom_text(size = 3, vjust = -0.25, position = position_dodge(width = 1)) +
          labs(x = var_nice[X], y = "Proportion", fill = "case_", title=unique(data[, "name"])) +
          scale_fill_brewer(palette = "Paired", name="case_", 
                            breaks=c("FALSE", "TRUE"), labels=c("Available", "Used")) +
          theme_light() +
          theme(legend.title = element_blank(),
                panel.grid.minor = element_blank(),
                text = element_text(size=15))+
          facet_grid(. ~ sex))
    }
    
    ## Grouped
  } else if (!is.null(var_prop) & !is.null(var2)) {
    
    if(sex==FALSE){
      
      plot <- map(var_prop, function(X)
        data %>% group_by(case_, group=data[,X], group2=data[,var2]) %>% summarize(n = n()) %>% 
          mutate(prop = n / sum(n), 
                 label = paste0(round(prop * 100, 1), "%")) %>% 
          ggplot(aes(factor(group2), prop, fill = case_, group=case_, label = label)) + 
          geom_col(position = position_dodge2()) +
          geom_text(size = 3, vjust = -0.25, position = position_dodge(width = 1)) +
          labs(x = var_nice[var2], y = "Proportion", fill = "case_", title=unique(data[, "name"])) +
          scale_fill_brewer(palette = "Paired", name="case_", 
                            breaks=c("FALSE", "TRUE"), labels=c("Available", "Used")) +
          theme_light() +
          theme(legend.title = element_blank(),
                panel.grid.minor = element_blank(),
                text = element_text(size=15)) +
          facet_grid(. ~ group))
      
    } else if(sex==TRUE){
      
      plot <- map(var_prop, function(X)
        data %>% group_by(sex, case_, group=data[,X], group2=data[,var2]) %>% summarize(n = n()) %>% 
          mutate(prop = n / sum(n), 
                 label = paste0(round(prop * 100, 1), "%")) %>% 
          ggplot(aes(factor(group2), prop, fill = case_, group=case_, label = label)) + 
          geom_col(position = position_dodge2()) +
          geom_text(size = 3, vjust = -0.25, position = position_dodge(width = 1)) +
          labs(x = var_nice[var2], y = "Proportion", fill = "case_", title=unique(data[, "name"])) +
          scale_fill_brewer(palette = "Paired", name="case_", 
                            breaks=c("FALSE", "TRUE"), labels=c("Available", "Used")) +
          theme_light() +
          theme(legend.title = element_blank(),
                panel.grid.minor = element_blank(),
                text = element_text(size=15)) +
          facet_grid(sex ~ group))
    }
    
  }
  
  ## Add sex in density plots?
  if(sex==TRUE & is.null(var2) & is.null(var_prop)) {
    
    plot <- map(plot, function(X)
      X + facet_grid(. ~ sex))
    
  } else if(sex==TRUE & !is.null(var2) & is.null(var_prop)) {
    
    plot <- map(plot, function(X)
      X + facet_grid(sex ~ data[,var2]))
    
  } else
    
    plot <- plot
  
  return(plot)
  
}


#### Load data ####

data_path <- " " #add the path to your data (e.g. "C:/Users/username/Downloads/")

## Lynx
lynxtrk_ssf_1h <- readRDS(paste0(data_path, "data/lynx_1_x_hour.rds"))
lynxtrk_ssf_1h$name <- "Lynx"
## Wild boar
boartrk_ssf_f <- readRDS(paste0(data_path, "data/wild_boar_females.rds"))
boartrk_ssf_m <- readRDS(paste0(data_path, "data/wild_boar_males.rds"))
boartrk_ssf <- rbind(boartrk_ssf_f, boartrk_ssf_m)
boartrk_ssf$name <- "Wild boar"
## Roe deer
roetrk_ssf_f <- readRDS(paste0(data_path, "data/roe_deer_females.rds"))
roetrk_ssf_m <- readRDS(paste0(data_path, "data/roe_deer_males.rds"))
roetrk_ssf <- rbind(roetrk_ssf_f, roetrk_ssf_m)
roetrk_ssf$name <- "Roe deer"
## Red deer
redtrk_ssf_f <- readRDS(paste0(data_path, "data/red_deer_females.rds"))
redtrk_ssf_m <- readRDS(paste0(data_path, "data/red_deer_males.rds"))
redtrk_ssf <- rbind(redtrk_ssf_f, redtrk_ssf_m)
redtrk_ssf$name <- "Red deer"

data_ls <- list(roe_deer=roetrk_ssf,
                red_deer=redtrk_ssf,
                wild_boar=boartrk_ssf,
                lynx_1h=lynxtrk_ssf_1h)

# clean workspace
rm(list=setdiff(ls(), c("data_ls", "data_path",
                        "std", "PlotStats",
                        "lynxtrk_ssf_1h", "boartrk_ssf",
                        "redtrk_ssf", "roetrk_ssf")))
gc()


#### Supporting information 4 ####

##### Table S1 ####
## Ungulates (divided per sex)
sl_tab_ung <- map(data_ls[-4], function(x)
  x %>%
    group_by(sex, case_) %>%
    summarize(
      Number = n(),
      Min=round(min(sl_),2),
      Median=round(median(sl_),2),
      Mean=round(mean(sl_),2),
      #SD=sd(sl_),
      Max=round(max(sl_),2)) %>% 
    mutate(case_ = ifelse(case_==FALSE, "Available", "Used"),
           sex = ifelse(sex=="f", "Females", "Males"))
     #%>% 
    #filter(case_=="Available")
  )
## lynx (not divided per sex)
sl_tab_lynx <- map(data_ls[4], function(x)
  x %>%
    mutate(sex="All") %>% 
    group_by(sex, case_) %>%
    summarize(
      Number = n(),
      Min=round(min(sl_),2),
      Median=round(median(sl_),2),
      Mean=round(mean(sl_),2),
      #SD=sd(sl_),
      Max=round(max(sl_),2)) %>% 
    mutate(case_ = ifelse(case_==FALSE, "Available", "Used"))
  #%>% 
  #filter(case_=="Available")
)
sl_tab <- c(sl_tab_ung, sl_tab_lynx)
sl_tab <- sl_tab %>% tibble::enframe() %>% tidyr::unnest(cols=c(name, value))
sl_tab <- sl_tab %>% 
  mutate(name = ifelse(name=="roe_deer", "Roe deer",
                       ifelse(name=="red_deer", "Red deer",
                              ifelse(name=="wild_boar", "Wild boar",
                                     ifelse(name=="lynx_1h", "Lynx", NA)))) %>% 
           factor(levels = c("Roe deer", "Red deer", "Wild boar", "Lynx"))) %>% 
  arrange(name) %>% 
  select(Species=name, Sex=sex, Step=case_, Number, Min, Median, Mean, Max)
sl_tab
# tab_df(sl_tab, file = paste0(data_path, "summary_step_length.doc"))


##### Figure S4 ####
## ungulates
sl_plot_ung <- map(data_ls[-4], function(x)
  PlotStats(x, var_dens="sl_", sex=TRUE)) %>% 
  unlist(recursive = FALSE)
sl_plot_ung$roe_deer <- sl_plot_ung$roe_deer + scale_x_continuous(breaks=c(0, 1000, 2000))
## lynx
sl_plot_lynx <- map(data_ls[4], function(x)
  PlotStats(x, var_dens="sl_")) %>% 
  unlist(recursive = FALSE)
sl_plots <- ggarrange(plotlist=c(sl_plot_ung, sl_plot_lynx), common.legend = TRUE)
# ggsave(filename="step_lenght.tiff", plot=sl_plots, device="tiff",
#        width=25, heigh=25, units="cm", dpi=500,
#        path=data_path, bg="white")


##### Figure S5 ####
tod_plot <- map(data_ls, function(x)
  PlotStats(x, var_prop="tod_suncalc_end", sex=TRUE)) %>% 
  unlist(recursive = FALSE)
tod_plots <- ggarrange(plotlist=tod_plot, common.legend = TRUE)
# ggsave(filename="time_of_day.tiff", plot=tod_plots, device="tiff",
#        width=25, heigh=25, units="cm", dpi=500,
#        path=data_path, bg="white")


##### Figure S6 ####
lynx_tod <- 
  lynxtrk_ssf_1h %>%
  #filter(case_==TRUE) %>% 
  mutate(hour1=hour(t1_), hour2=hour(t2_)) %>%
  select(hour1, hour2)
lynx_tod <- data.frame(hour=c(lynx_tod$hour1, lynx_tod$hour2))

lynx_tod_plot <- ggplot(lynx_tod, aes(x = hour)) + 
  geom_histogram(stat="count") +
  #geom_density(colour="grey", fill="grey") +
  labs(x = "Hour", y = "Density") +
  scale_x_continuous(breaks =c(0:23), labels=c(paste0(0:23, ":00"))) +
  theme_light() +
  theme(legend.title = element_blank(),
        panel.grid.minor = element_blank(),
        text = element_text(size=15),
        axis.text.x = element_text(angle=90, vjust=0.5))
# ggsave(filename="lynx_tod.tiff", plot=lynx_tod_plot, device="tiff",
#        width=25, heigh=25, units="cm", dpi=500,
#        path=data_path, bg="white")


##### Figure S7 ####
cross_plot <- map(data_ls, function(x)
  PlotStats(x, var_prop="crossings", sex=TRUE)) %>% 
  unlist(recursive = FALSE)
cross_plots <- ggarrange(plotlist=cross_plot, common.legend = TRUE)
# ggsave(filename="road_crossing.tiff", plot=cross_plots, device="tiff",
#        width=25, heigh=25, units="cm", dpi=500,
#        path=data_path, bg="white")


##### Figure S8 ####
## lynx
id_cross_lynx <- lynxtrk_ssf_1h %>%
  mutate(crossings_n = ifelse(crossings==TRUE, 1, 0),
         case_=ifelse(case_==FALSE, "Available", "Used")) %>%
  group_by(id, sex, case_) %>% summarize(n_cross=sum(crossings_n)) %>%
  arrange(n_cross) %>% mutate(id=factor(id, levels=unique(id))) %>% 
  ggplot(aes(x=reorder(id, n_cross), y=n_cross, label=n_cross,
             fill=sex
  )) +
  geom_bar(stat="identity") +
  geom_text(size = 3, hjust = 0.5) +
  scale_fill_brewer(palette = "Pastel2", name="sex", direction=-1,
                    breaks=c("f", "m"), labels=c("Females", "Males")) +
  coord_flip() +
  labs(x="Animal ID", y="Number of road crossings", title="Lynx") +
  theme(legend.title = element_blank(), legend.position = "top", text = element_text(size=15)) +
  facet_grid(. ~ case_, scales = "free_x")
# ggsave(filename="road_crossing_lynx_id.tiff", plot=id_cross_lynx, device="tiff", 
#        width=25, heigh=25, units="cm", dpi=500,
#        path=data_path, bg="white")
## wild boar
id_cross_boar <- boartrk_ssf %>%
  mutate(crossings_n = ifelse(crossings==TRUE, 1, 0),
         case_=ifelse(case_==FALSE, "Available", "Used")) %>%
  group_by(id, sex, case_) %>% summarize(n_cross=sum(crossings_n)) %>%
  arrange(n_cross) %>% mutate(id=factor(id, levels=unique(id))) %>% 
  ggplot(aes(x=reorder(id, n_cross), y=n_cross, label=n_cross,
             fill=sex
  )) +
  geom_bar(stat="identity") +
  geom_text(size = 3, hjust = 0.5) +
  scale_fill_brewer(palette = "Pastel2", name="sex", direction=-1,
                    breaks=c("f", "m"), labels=c("Females", "Males")) +
  coord_flip() +
  labs(x="Animal ID", y="Number of road crossings", title="Wild boar") +
  theme(legend.title = element_blank(), legend.position = "top", text = element_text(size=15)) +
  facet_grid(. ~ case_, scales = "free_x")
# ggsave(filename="road_crossing_boar_id.tiff", plot=id_cross_boar, device="tiff", 
#        width=25, heigh=25, units="cm", dpi=500,
#        path=data_path, bg="white")
## roe deer
id_cross_roe <- roetrk_ssf %>%
  mutate(crossings_n = ifelse(crossings==TRUE, 1, 0),
         case_=ifelse(case_==FALSE, "Available", "Used")) %>%
  group_by(id, sex, case_) %>% summarize(n_cross=sum(crossings_n)) %>%
  arrange(n_cross) %>% mutate(id=factor(id, levels=unique(id))) %>% 
  ggplot(aes(x=reorder(id, n_cross), y=n_cross, label=n_cross,
             fill=sex
  )) +
  geom_bar(stat="identity") +
  geom_text(size = 3, hjust = 0.5) +
  scale_fill_brewer(palette = "Pastel2", name="sex", direction=-1,
                    breaks=c("f", "m"), labels=c("Females", "Males")) +
  coord_flip() +
  labs(x="Animal ID", y="Number of road crossings", title="Roe deer") +
  theme(legend.title = element_blank(), legend.position = "top",
        title = element_text(size=15)) +
  facet_grid(. ~ case_, scales = "free_x")
# ggsave(filename="road_crossing_roe_deer_id.tiff", plot=id_cross_roe, device="tiff", 
#        width=25, heigh=25, units="cm", dpi=500,
#        path=data_path, bg="white")
## red deer
id_cross_red <- redtrk_ssf %>% 
  mutate(crossings_n = ifelse(crossings==TRUE, 1, 0),
                      case_=ifelse(case_==FALSE, "Available", "Used")) %>%
  group_by(id, sex, case_) %>% summarize(n_cross=sum(crossings_n)) %>%
  arrange(n_cross) %>% mutate(id=factor(id, levels=unique(id))) %>% 
  ggplot(aes(x=reorder(id, n_cross), y=n_cross, label=n_cross,
             fill=sex
  )) +
  geom_bar(stat="identity") +
  geom_text(size = 3, hjust = 0.5) +
  scale_fill_brewer(palette = "Pastel2", name="sex", direction=-1,
                    breaks=c("f", "m"), labels=c("Females", "Males")) +
  coord_flip() +
  labs(x="Animal ID", y="Number of road crossings", title="Red deer") +
  theme(legend.title = element_blank(), legend.position = "top",
        title = element_text(size=15)) +
  facet_grid(. ~ case_, scales = "free_x")
# ggsave(filename="road_crossing_red_deer_id.tiff", plot=id_cross_red, device="tiff", 
#        width=25, heigh=25, units="cm", dpi=500,
#        path=data_path, bg="white")

