#### Manuscript: OIK-10433
#### Title: Risk response towards roads is consistent across multiple species
##          in a temperate forest ecosystem
#### Date (creation): 12/2023
#### Date (last update): 01/2024
#### Purpose: Run models for each species and sex (Table 2)


#### Load packages ####
# Install glmmTMB in the following way to avoid warnings about detection of packages inconsistency (and related errors when running the models):
# first install TMB (from source), then glmmTMB (from source):
# NB: 'Rtools' needed for installation of R packages from source or building R from source (https://cran.rstudio.com/bin/windows/Rtools/)
# 1) install.packages('TMB', type = 'source')
# 2) install.packages('glmmTMB', type = 'source')
# or download the package versions needed, but always install TMB first and glmmTMB after
# see -> https://github.com/glmmTMB/glmmTMB/issues/791
library(glmmTMB) # version 1.1.2.3
library(dplyr)
library(sjPlot)


#### Set data path ####
data_path <- " " #add the path to your data (e.g. "C:/Users/username/Downloads/")


#### LYNX ####

##### Load data ####
lynxtrk_ssf_1h <- readRDS(paste0(data_path, "data/lynx_1_x_hour.rds"))
lynxtrk_ssf_2xd <- readRDS(paste0(data_path, "data/lynx_2_x_day.rds"))

##### Fine scale (1 fix per hour) ####
system.time(
  lynxmodel_1h <- glmmTMB(y ~ -1 + log_sl + cos_ta +
                         log_dist_road_end + I(log_dist_road_end^2) + crossings +
                         cover_end + I(cover_end^2) + cover_end:night_suncalc_end + cover_end:twilight_suncalc_end +
                         understory_end + I(understory_end^2) + understory_end:night_suncalc_end + understory_end:twilight_suncalc_end +
                         ruggedness_end + I(ruggedness_end^2) +
                         log_dist_road_start:cover_end + log_dist_road_start:understory_end +
                         crossings:cover_end + crossings:understory_end +
                         log_sl:log_dist_road_start + log_sl:crossings +
                         log_dist_road_end:night_suncalc_end + log_dist_road_end:twilight_suncalc_end + log_dist_road_end:season_end +
                         crossings:night_suncalc_end + crossings:twilight_suncalc_end + crossings:season_end +
                         log_sl:night_suncalc_start + log_sl:twilight_suncalc_start + log_sl:season_start + 
                         (1 | id_step_id) +
                         (0 + log_dist_road_end | id) +
                         (0 + crossings | id),
                       family = poisson,
                       data = lynxtrk_ssf_1h,
                       map=list(theta=factor(c(NA,1,2))),
                       start=list(theta=c(log(1e3),rep(0,2))))
)#<1min
# saveRDS(lynxmodel_1h, paste0(data_path, "model_lynx_1h.rds"))
( lynxmodel_1h_sum <- summary(lynxmodel_1h) )
lynxmodel_1h$sdr$pdHess #TRUE


##### Coarse scale (2 fixes per day) ####
## Exclude twilight because not represented 
system.time(
  lynxmodel_2xd <- glmmTMB(y ~ -1 + log_sl + cos_ta +
                            log_dist_road_end + I(log_dist_road_end^2) + crossings +
                            cover_end + I(cover_end^2) + cover_end:night_suncalc_end  +
                            understory_end + I(understory_end^2) + understory_end:night_suncalc_end +
                            ruggedness_end + I(ruggedness_end^2) +
                            log_dist_road_start:cover_end + log_dist_road_start:understory_end +
                            crossings:cover_end + crossings:understory_end +
                            log_sl:log_dist_road_start + log_sl:crossings +
                            log_dist_road_end:night_suncalc_end + log_dist_road_end:season_end +
                            crossings:night_suncalc_end + crossings:season_end +
                            log_sl:night_suncalc_start + log_sl:season_start + 
                            (1 | id_step_id) +
                            (0 + log_dist_road_end | id) +
                            (0 + crossings | id),
                          family = poisson,
                          data = lynxtrk_ssf_2xd,
                          map=list(theta=factor(c(NA,1,2))),
                          start=list(theta=c(log(1e3),rep(0,2))))
)#<1min
# saveRDS(lynxmodel_2xd, paste0(data_path, "model_lynx_2xd.rds"))
( lynxmodel_2xd_sum <- summary(lynxmodel_2xd) )
lynxmodel_2xd$sdr$pdHess #TRUE


#### WILD BOAR ####

##### Load data ####
boartrk_ssf_m<-readRDS(paste0(data_path, "data/boartrk_ssf_m.rds"))
boartrk_ssf_f<-readRDS(paste0(data_path, "data/boartrk_ssf_f.rds"))

##### Male model ####
system.time(
  boarmalemodel <- glmmTMB(y ~ -1 + log_sl + cos_ta +
                             log_dist_road_end + I(log_dist_road_end^2) + crossings +
                             cover_end + I(cover_end^2) + cover_end:night_suncalc_end + cover_end:twilight_suncalc_end +
                             understory_end + I(understory_end^2) + understory_end:night_suncalc_end + understory_end:twilight_suncalc_end +
                             ruggedness_end + I(ruggedness_end^2) +
                             log_dist_road_start:cover_end + log_dist_road_start:understory_end +
                             crossings:cover_end + crossings:understory_end +
                             log_sl:log_dist_road_start + log_sl:crossings +
                             log_dist_road_end:night_suncalc_end + log_dist_road_end:twilight_suncalc_end + log_dist_road_end:season_end +
                             crossings:night_suncalc_end + crossings:twilight_suncalc_end + crossings:season_end +
                             log_sl:night_suncalc_start + log_sl:twilight_suncalc_start + log_sl:season_start + 
                             (1 | id_step_id) +
                             (0 + log_dist_road_end | id) +
                             (0 + crossings | id),
                           family = poisson,
                           data = boartrk_ssf_m,
                           map=list(theta=factor(c(NA,1,2))),
                           start=list(theta=c(log(1e3),rep(0,2))))
) #8min
# saveRDS(boarmalemodel, paste0(data_path, "model_boar_male.rds"))
( boarmalemodel_sum <- summary(boarmalemodel) )
boarmalemodel$sdr$pdHess #TRUE


##### Female model ####
## Exclude road crossings because not represented enough
system.time(
  boarfemalemodel <- glmmTMB(y ~ -1 + log_sl + cos_ta +
                                       log_dist_road_end + I(log_dist_road_end^2) +
                                       cover_end + I(cover_end^2) + cover_end:night_suncalc_end + cover_end:twilight_suncalc_end +
                                       understory_end + I(understory_end^2) + understory_end:night_suncalc_end + understory_end:twilight_suncalc_end +
                                       ruggedness_end + I(ruggedness_end^2) +
                                       log_dist_road_start:cover_end + log_dist_road_start:understory_end +
                                       log_sl:log_dist_road_start +
                                       log_dist_road_end:night_suncalc_end + log_dist_road_end:twilight_suncalc_end + log_dist_road_end:season_end +
                                       log_sl:night_suncalc_start + log_sl:twilight_suncalc_start + log_sl:season_start +
                                       (1 | id_step_id) +
                                       (0 + log_dist_road_end | id),
                                     family = poisson,
                                     data = boartrk_ssf_f,
                                     map=list(theta=factor(c(NA,1))),
                                     start=list(theta=c(log(1e3),0)))
) #8 min
# saveRDS(boarfemalemodel, paste0(data_path, "model_boar_female.rds"))
( boarfemalemodel_sum <- summary(boarfemalemodel) )
boarfemalemodel$sdr$pdHess #TRUE


#### RED DEER ####

##### Load data ####
redtrk_ssf_m<-readRDS(paste0(data_path, "data/redtrk_ssf_m.rds"))
redtrk_ssf_f<-readRDS(paste0(data_path, "data/redtrk_ssf_f.rds"))

##### Male model ####
system.time(
  redmalemodel <- glmmTMB(y ~ -1 + log_sl + cos_ta +
                            log_dist_road_end + I(log_dist_road_end^2) + crossings +
                            cover_end + I(cover_end^2) + cover_end:night_suncalc_end + cover_end:twilight_suncalc_end +
                            understory_end + I(understory_end^2) + understory_end:night_suncalc_end + understory_end:twilight_suncalc_end +
                            ruggedness_end + I(ruggedness_end^2) +
                            log_dist_road_start:cover_end + log_dist_road_start:understory_end +
                            crossings:cover_end + crossings:understory_end +
                            log_sl:log_dist_road_start + log_sl:crossings +
                            log_dist_road_end:night_suncalc_end + log_dist_road_end:twilight_suncalc_end + log_dist_road_end:season_end +
                            crossings:night_suncalc_end + crossings:twilight_suncalc_end + crossings:season_end +
                            log_sl:night_suncalc_start + log_sl:twilight_suncalc_start + log_sl:season_start + 
                            (1 | id_step_id) +
                            (0 + log_dist_road_end | id) +
                            (0 + crossings | id),
                          family = poisson,
                          data = redtrk_ssf_m,
                          map=list(theta=factor(c(NA,1,2))),
                          start=list(theta=c(log(1e3),rep(0,2))))
) # ~ 40 min
# saveRDS(redmalemodel, paste0(data_path, "model_red_male.rds"))
( redmalemodel_sum <- summary(redmalemodel) )
redmalemodel$sdr$pdHess #TRUE


##### Female model ####
system.time(
  redfemalemodel <- glmmTMB(y ~ -1 + log_sl + cos_ta +
                               log_dist_road_end + I(log_dist_road_end^2) + crossings +
                               cover_end + I(cover_end^2) + cover_end:night_suncalc_end + cover_end:twilight_suncalc_end +
                               understory_end + I(understory_end^2) + understory_end:night_suncalc_end + understory_end:twilight_suncalc_end +
                               ruggedness_end + I(ruggedness_end^2) +
                               log_dist_road_start:cover_end + log_dist_road_start:understory_end +
                               crossings:cover_end + crossings:understory_end +
                               log_sl:log_dist_road_start + log_sl:crossings +
                               log_dist_road_end:night_suncalc_end + log_dist_road_end:twilight_suncalc_end + log_dist_road_end:season_end +
                               crossings:night_suncalc_end + crossings:twilight_suncalc_end + crossings:season_end +
                               log_sl:night_suncalc_start + log_sl:twilight_suncalc_start + log_sl:season_start +
                               (1 | id_step_id) +
                               (0 + log_dist_road_end | id) +
                               (0 + crossings | id),
                             family = poisson,
                             data = redtrk_ssf_f,
                             map=list(theta=factor(c(NA,1,2))),
                             start=list(theta=c(log(1e3),rep(0,2))),
                             control=glmmTMBControl(optimizer=optim, optArgs=list(method="BFGS")))
) #2.5h
# different optimizer only needed for glmmTMB version 1.1.2.3 to avoid warning 'function evaluation limit'
# warning disappear with more recent versions of TMB (1.9.8) and glmmTMB (1.1.8) or by changing optimizer or number of iterations
# saveRDS(redfemalemodel, paste0(data_path, "model_red_female.rds"))
( redfemalemodel_sum <- summary(redfemalemodel) )
redfemalemodel$sdr$pdHess #TRUE


#### ROE DEER ####

roetrk_ssf_m<-readRDS(paste0(data_path, "data/roetrk_ssf_m.rds"))
roetrk_ssf_f<-readRDS(paste0(data_path, "data/roetrk_ssf_f.rds"))

##### Male model ####
system.time(
  roemalemodel <- glmmTMB(y ~ -1 + log_sl + cos_ta +
                         log_dist_road_end + I(log_dist_road_end^2) + crossings +
                         cover_end + I(cover_end^2) + cover_end:night_suncalc_end + cover_end:twilight_suncalc_end +
                         understory_end + I(understory_end^2) + understory_end:night_suncalc_end + understory_end:twilight_suncalc_end +
                         ruggedness_end + I(ruggedness_end^2) +
                         log_dist_road_start:cover_end + log_dist_road_start:understory_end +
                         crossings:cover_end + crossings:understory_end +
                         log_sl:log_dist_road_start + log_sl:crossings +
                         log_dist_road_end:night_suncalc_end + log_dist_road_end:twilight_suncalc_end + log_dist_road_end:season_end +
                         crossings:night_suncalc_end + crossings:twilight_suncalc_end + crossings:season_end +
                         log_sl:night_suncalc_start + log_sl:twilight_suncalc_start + log_sl:season_start + 
                         (1 | id_step_id) +
                         (0 + log_dist_road_end | id) +
                         (0 + crossings | id),
                       family = poisson,
                       data = roetrk_ssf_m,
                       map=list(theta=factor(c(NA,1,2))),
                       start=list(theta=c(log(1e3),rep(0,2))))
) # ~17 min
# saveRDS(roemalemodel, paste0(data_path, "model_roe_male.rds"))
( roemalemodel_sum <- summary(roemalemodel) )
roemalemodel$sdr$pdHess #TRUE


##### Female model ####
system.time(
  roefemalemodel <- glmmTMB(y ~ -1 + log_sl + cos_ta +
                           log_dist_road_end + I(log_dist_road_end^2) + crossings +
                           cover_end + I(cover_end^2) + cover_end:night_suncalc_end + cover_end:twilight_suncalc_end +
                           understory_end + I(understory_end^2) + understory_end:night_suncalc_end + understory_end:twilight_suncalc_end +
                           ruggedness_end + I(ruggedness_end^2) +
                           log_dist_road_start:cover_end + log_dist_road_start:understory_end +
                           crossings:cover_end + crossings:understory_end +
                           log_sl:log_dist_road_start + log_sl:crossings +
                           log_dist_road_end:night_suncalc_end + log_dist_road_end:twilight_suncalc_end + log_dist_road_end:season_end +
                           crossings:night_suncalc_end + crossings:twilight_suncalc_end + crossings:season_end +
                           log_sl:night_suncalc_start + log_sl:twilight_suncalc_start + log_sl:season_start + 
                           (1 | id_step_id) +
                           (0 + log_dist_road_end | id) +
                           (0 + crossings | id),
                         family = poisson,
                         data = roetrk_ssf_f,
                         map=list(theta=factor(c(NA,1,2))),
                         start=list(theta=c(log(1e3),rep(0,2))))
) # ~20 min
# saveRDS(roefemalemodel, paste0(data_path, "model_roe_female.rds"))
( roefemalemodel_sum <- summary(roefemalemodel) )
roefemalemodel$sdr$pdHess #TRUE


#### Tables ####

##### Table 2 ####

model_ls <- list(roefemalemodel, roemalemodel, 
                 redfemalemodel, redmalemodel, 
                 boarfemalemodel, boarmalemodel, 
                 lynxmodel_1h)

variable_name <- c("ln(Step Length)", "cos(Turning Angle)",
                   "ln(Distance to road)", "ln(Distance to road)²", "Road Crossing",
                   "Canopy Cover", "Canopy Cover²",  "Understory", "Understory²", "Ruggedness", "Ruggedness²",
                   "Canopy Cover : Night", "Canopy Cover : Twilight", "Understory : Night", "Understory : Twilight",
                   "Canopy Cover : ln(Distance to road)Start", "Understory : ln(Distance to road)Start",
                   "Road Crossing : Canopy Cover", "Road Crossing : Understory",
                   "ln(Step Length) : ln(Distance to road)Start", "ln(Step Length) : Road Crossing",
                   "ln(Distance to road) : Night", "ln(Distance to road) : Twilight", "ln(Distance to road) : Season",
                   "Road Crossing : Night", "Road Crossing : Twilight", "Road Crossing : Season",
                   "ln(Step Length) : NightStart", "ln(Step Length) : TwilightStart", "ln(Step Length) : SeasonStart")

tab_model(model_ls, transform = NULL, show.intercept=FALSE,
          show.obs = FALSE, show.ci = FALSE, show.p=TRUE, show.se = TRUE,
          show.icc = FALSE, show.r2 = FALSE, show.re.var=FALSE, show.ngroups=FALSE,
          digits=3,
          rm.terms = "phi", string.est = "Estimates", string.pred = "Terms",
          string.se="", collapse.se = TRUE,
          pred.labels = variable_name,
          order.terms = c(1, 2, 28:30,
                          6, 7, 12, 13, 8, 9, 14, 15, 10, 11,
                          3:5, 20, 21,
                          16:19, 
                          22:27),
          dv.labels=c("Roe deer Females", "Roe deer Males",
                      "Red deer Females", "Red deer Males",
                      "Wild boar Females", "Wild boar Males",
                      "Lynx"),
          file=paste0(data_path, "sum_tab.doc"))
# If memory allocation fails, run species separately separately!
# If the file is not saved in the folder, do run print() around tab_model(): 'print(tab_model(...))'


##### Table S2 ####
## Lynx (2 fixes per day)
tab_model(list(lynxmodel_1h, lynxmodel_2xd), transform = NULL, show.intercept=FALSE,
          show.obs = FALSE, show.ci = FALSE, show.p=TRUE, show.se = TRUE,
          show.icc = FALSE, show.r2 = FALSE, show.re.var=FALSE, show.ngroups=FALSE,
          digits=3, 
          rm.terms = "phi", string.est = "Estimates", string.pred = "Terms",
          string.se="", collapse.se = TRUE,
          pred.labels = variable_name,
          order.terms = c(1, 2, 28:30,
                          6, 7, 12, 13, 8, 9, 14, 15, 10, 11,
                          3:5, 20, 21,
                          16:19, 
                          22:27),
          dv.labels=c("Lynx (1 per hour)", "Lynx (2 per day)"),
          file=paste0(data_path, "sum_tab_lynx_1xh_2xd.doc"))

