#### Manuscript: OIK-10433
#### Title: Risk response towards roads is consistent across multiple species
##          in a temperate forest ecosystem
#### Date (creation): 12/2023
#### Date (last update): 01/2024
#### Purpose: Create displacement plots (Figure 3)


#### Load packages ####

library(amt) # version 0.1.6
library(glmmTMB) # version 1.1.2.3
library(ggplot2)
library(ggpubr)
library(rphylopic)


#### Load functions ####

#### Displacement function
DisplFun <- function(sl_distr_list, model_list, var){
  
  # create empty list of plot to fill
  disp_ggplot <- list()
  
  if(var=="crossings"){
    
    for (i in 1:length(sl_distr_list)) {
      
      # take one step length distribution and model at a time (one per species-sex)
      sl_distr <- sl_distr_list[[i]]
      model <- model_list[[i]]
      model_name <- as.character(model_list[[i]]$call$data)
      x <- 0:1
      
      # create data frame
      speed_pop <- tibble(
        cross = x,
        scale = sl_distr$params$scale,
        shape = sl_distr$params$shape + fixef(model)$cond["log_sl"] +
          fixef(model)$cond["log_sl:crossings"] * x,
        speed = scale * shape
      )
      
      # Let's add CI
      vc <- stats::vcov(model)
      
      k0 <- sl_distr$params$shape
      q0 <- sl_distr$params$scale
      b1 <- fixef(model)$cond["log_sl"]
      b2 <- fixef(model)$cond["log_sl:crossings"]
      var_k0 <- sl_distr$vcov[2, 2]
      var_q0 <- sl_distr$vcov[1, 1]
      var_b1 <- vc[[1]]["log_sl", "log_sl"]
      var_b2 <- vc[[1]]["log_sl:crossings", "log_sl:crossings"]
      cov_k0_q0 <- sl_distr$vcov[2, 1]
      cov_b1_b2 <- vc[[1]][22, 2]
      
      var_speed <- var_q0 * (k0 + b1 + b2 * x)^2 + var_k0 * q0^2 + var_b1 * q0^2 +
        var_b2 * (q0 * x)^2 + 2 * (
          cov_k0_q0 * (k0 + b1 + b2 * x) * q0 +
            cov_b1_b2 * q0 * q0 * x
        )
      
      speed_pop$se <- sqrt(var_speed)
      speed_pop$lci <- speed_pop$speed - 1.96 * speed_pop$se
      speed_pop$uci <- speed_pop$speed + 1.96 * speed_pop$se
      speed_pop$model <- model_name
      
      # plot
      disp_ggplot[[i]] <- ggplot(speed_pop, aes(cross, speed)) +
        geom_pointrange(aes(ymin = lci, ymax = uci), size=0.8) +
        scale_x_continuous(breaks = c(0,1)) +
        ggtitle(model_name) +
        theme_light() +
        labs(x = "Crossing",
             y = "Expected displacement [m per 1h]")
      
    }
  } else if(var=="log_dist_road_start") {
    
    for (i in 1:length(sl_distr_list)) {
      
      # take one step length distribution and model at a time (one per species-sex)
      sl_distr <- sl_distr_list[[i]]
      model <- model_list[[i]]
      model_name <- as.character(model_list[[i]]$call$data)
      # x will be from min to max observed road distance (changes for each species!)
      x <- seq(from = min(model_list[[i]]$frame$log_dist_road_start), to = max(model_list[[i]]$frame$log_dist_road_start), length.out = 100)
      
      # create data frame
      speed_pop <- tibble(
        dist.road = x,
        scale = sl_distr$params$scale,
        shape = sl_distr$params$shape + fixef(model)$cond["log_sl"] +
          fixef(model)$cond["log_sl:log_dist_road_start"] * x,
        speed = scale * shape
      )
      
      # Let's add CI
      vc <- stats::vcov(model)
      
      k0 <- sl_distr$params$shape
      q0 <- sl_distr$params$scale
      b1 <- fixef(model)$cond["log_sl"]
      b2 <- fixef(model)$cond["log_sl:log_dist_road_start"]
      var_k0 <- sl_distr$vcov[2, 2]
      var_q0 <- sl_distr$vcov[1, 1]
      var_b1 <- vc[[1]]["log_sl", "log_sl"]
      var_b2 <- vc[[1]]["log_sl:log_dist_road_start", "log_sl:log_dist_road_start"]
      cov_k0_q0 <- sl_distr$vcov[2, 1]
      cov_b1_b2 <- vc[[1]][21, 2]
      
      var_speed <- var_q0 * (k0 + b1 + b2 * x)^2 + var_k0 * q0^2 + var_b1 * q0^2 +
        var_b2 * (q0 * x)^2 + 2 * (
          cov_k0_q0 * (k0 + b1 + b2 * x) * q0 +
            cov_b1_b2 * q0 * q0 * x
        )
      
      speed_pop$se <- sqrt(var_speed)
      speed_pop$lci <- speed_pop$speed - 1.96 * speed_pop$se
      speed_pop$uci <- speed_pop$speed + 1.96 * speed_pop$se
      speed_pop$model <- model_name
      
      # unscale distance to road
      speed_pop$dist.road <- attr(model_list[[i]]$frame[,"log_dist_road_start"], "scaled:scale")*speed_pop$dist.road + attr(model_list[[i]]$frame[,"log_dist_road_start"], "scaled:center")
      # back-transform distance to road
      speed_pop$dist.road <- exp(speed_pop$dist.road)
      
      # plot
      disp_ggplot[[i]] <- ggplot(speed_pop, aes(dist.road, speed)) +
        geom_ribbon(aes(ymin = lci, ymax = uci), alpha = 0.4) +
        geom_line() +
        ggtitle(model_name) +
        theme_light() +
        labs(x = "Distance to Road [m]",
             y = "Expected displacement [m per 1h]")
      
    }
    
  }
  
  return(disp_ggplot)
  
}


#### Load data ####

data_path <- " " #add the path to your data (e.g. "C:/Users/username/Downloads/")

## Load datasets
# Lynx
lynxtrk_ssf_1h <- readRDS(paste0(data_path, "data/lynx_1_x_hour.rds"))
# Wild boar
boartrk_ssf_f <- readRDS(paste0(data_path, "data/wild_boar_females.rds"))
boartrk_ssf_m <- readRDS(paste0(data_path, "data/wild_boar_males.rds"))
# Roe deer
roetrk_ssf_f <- readRDS(paste0(data_path, "data/roe_deer_females.rds"))
roetrk_ssf_m <- readRDS(paste0(data_path, "data/roe_deer_males.rds"))
# Red deer
redtrk_ssf_f <- readRDS(paste0(data_path, "data/red_deer_females.rds"))
redtrk_ssf_m <- readRDS(paste0(data_path, "data/red_deer_males.rds"))
## Create list of dataset
data_ls <- list(roe_deer_males=roetrk_ssf_m, roe_deer_females=roetrk_ssf_f,
                red_deer_males=redtrk_ssf_m, red_deer_females=redtrk_ssf_f,
                wild_boar_males=boartrk_ssf_m, wild_boar_females=boartrk_ssf_f,
                lynx_1h=lynxtrk_ssf_1h
)

## Load models
lynxmodel_1h <- readRDS(paste0(data_path, "model_lynx_1h.rds"))
boarfemalemodel <- readRDS(paste0(data_path, "model_boar_female.rds"))
boarmalemodel <- readRDS(paste0(data_path, "model_boar_male.rds"))
roefemalemodel <- readRDS(paste0(data_path, "model_roe_female.rds"))
roemalemodel <- readRDS(paste0(data_path, "model_roe_male.rds"))
redfemalemodel <- readRDS(paste0(data_path, "model_red_female.rds"))
redmalemodel <- readRDS(paste0(data_path, "model_red_male.rds"))
## Create model list
model_ls <- list(roemalemodel=roemalemodel, roefemalemodel=roefemalemodel,
                 redmalemodel=redmalemodel, redfemalemodel=redfemalemodel,
                 boarmalemodel=boarmalemodel, boarfemalemodel=boarfemalemodel,
                 lynxmodel_1h=lynxmodel_1h)

## Exclude records with NAs that were excluded in the model
unique(c(
names(which(sapply(lynxtrk_ssf_1h, function(x) any(is.na(x))))),
names(which(sapply(boartrk_ssf_f, function(x) any(is.na(x))))),
names(which(sapply(boartrk_ssf_m, function(x) any(is.na(x))))),
names(which(sapply(roetrk_ssf_f, function(x) any(is.na(x))))),
names(which(sapply(roetrk_ssf_m, function(x) any(is.na(x))))),
names(which(sapply(redtrk_ssf_f, function(x) any(is.na(x))))),
names(which(sapply(redtrk_ssf_m, function(x) any(is.na(x)))))
))
# cover_end and understory_end
data_ls <- map(data_ls, function(x) 
  filter(x, !is.na(understory_end) & !is.na(cover_end))
)
names(data_ls)
names(model_ls)
# check
unique(c(
  names(which(sapply(data_ls[[1]], function(x) any(is.na(x))))),
  names(which(sapply(data_ls[[2]], function(x) any(is.na(x))))),
  names(which(sapply(data_ls[[3]], function(x) any(is.na(x))))),
  names(which(sapply(data_ls[[4]], function(x) any(is.na(x))))),
  names(which(sapply(data_ls[[5]], function(x) any(is.na(x))))),
  names(which(sapply(data_ls[[6]], function(x) any(is.na(x))))),
  names(which(sapply(data_ls[[7]], function(x) any(is.na(x)))))
))
check <- rep(NA, length(data_ls))
for (i in 1:length(data_ls)){
check[i] <- nrow(model_ls[[i]]$frame) == nrow(data_ls[[i]])
}
check #all true

#clean workspace
rm(check, i,
   roetrk_ssf_f, roetrk_ssf_m, redtrk_ssf_f, redtrk_ssf_m, boartrk_ssf_f, boartrk_ssf_m, lynxtrk_ssf_1h,
   roefemalemodel, roemalemodel, redfemalemodel, redmalemodel, boarfemalemodel, boarmalemodel, lynxmodel_1h)
gc()

## Get silhouettes with package 'rphylopic' to add later on arranged plots
pick_phylopic(name = "Sus scrofa", n = 5, view = 5)
boar.img <- get_phylopic(uuid = "87047da1-b40e-4b31-8492-4db262f129f5")
roe.img <- get_phylopic(uuid = get_uuid(name="Capreolus capreolus", n=1))
pick_phylopic(name = "Cervus elaphus", n = 2, view = 2)
red.img <- get_phylopic(uuid = "cc03f5c2-933f-4c40-9c64-7f8727556fdb")
pick_phylopic(name = "Lynx lynx", n = 4, view = 4)
lynx.img <- get_phylopic(uuid = "27a2173a-5903-46fc-83c5-29ed7f421046")

#### Displacement ####

##### Step length distribution ####

## Get step length gamma distribution from all models
system.time(
  sl_distr_ls <- purrr::map(data_ls, function(X) {
    fit_distr(X$sl_, "gamma")})
) # < 2 min


##### Displacement ~ Road Crossings ####

## exclude wild boar females for which road crossing was exlcuded from the model
displ_road_cross <- DisplFun(sl_distr_ls[-6], model_ls[-6], var = "crossings")
displ_road_cross

length(displ_road_cross)
displ_road_cross_df <- rbind(displ_road_cross[[1]][["data"]],
                             displ_road_cross[[2]][["data"]],
                             displ_road_cross[[3]][["data"]],
                             displ_road_cross[[4]][["data"]],
                             displ_road_cross[[5]][["data"]],
                             displ_road_cross[[6]][["data"]])

displ_road_cross_df <- displ_road_cross_df %>% mutate(Crossing = ifelse(cross==0, "no", "yes") %>% factor(levels=c("no", "yes")),
                                                      species = ifelse(grepl("roe", model), "Roe deer",
                                                                       ifelse(grepl("red", model), "Red deer",
                                                                              ifelse(grepl("boar", model), "Wild boar",
                                                                                     ifelse(grepl("lynx", model), "Lynx", NA)))) %>% factor(),
                                                      Sex = ifelse(grepl("_f", model), "Females",
                                                                   ifelse(grepl("_m", model), "Males", "Lynx")) %>% factor())
displ_road_cross_df$species <- factor(displ_road_cross_df$species, levels=c("Roe deer", "Red deer", "Wild boar", "Lynx"))
displ_road_cross_df$species
displ_road_cross_df$Sex <- factor(displ_road_cross_df$Sex, levels=c("Females", "Males", "Lynx"))
displ_road_cross_df$Sex

displ_road_cross_df %>% arrange(speed) %>% View()

## Add wild boar female in the dataset (all NAs), to keep it in the plot legend
displ_road_cross_df
wild_boar_females_cross <- filter(displ_road_cross_df, species=="Wild boar")
wild_boar_females_cross$scale <- sl_distr_ls$wild_boar_females$params$scale
wild_boar_females_cross$shape <- NA
wild_boar_females_cross$speed <- NA
wild_boar_females_cross$se <- NA
wild_boar_females_cross$lci <- NA
wild_boar_females_cross$uci <- NA
wild_boar_females_cross$model <- "boartrk_ssf_f"
wild_boar_females_cross$Sex <- "Females"
displ_road_cross_df <- rbind(displ_road_cross_df, wild_boar_females_cross)
displ_road_cross_df <- displ_road_cross_df %>% arrange(species, Sex)
rm(wild_boar_females_cross)


##### Displacement ~ Distance to Roads ####

displ_dist_road <- DisplFun(sl_distr_ls, model_ls, var = "log_dist_road_start")
displ_dist_road

displ_dist_road_df <- rbind(displ_dist_road[[1]][["data"]],
                            displ_dist_road[[2]][["data"]],
                            displ_dist_road[[3]][["data"]],
                            displ_dist_road[[4]][["data"]],
                            displ_dist_road[[5]][["data"]],
                            displ_dist_road[[6]][["data"]],
                            displ_dist_road[[7]][["data"]])

displ_dist_road_df <- displ_dist_road_df %>% mutate(species = ifelse(grepl("roe", model), "Roe deer",
                                                                     ifelse(grepl("red", model), "Red deer",
                                                                            ifelse(grepl("boar", model), "Wild boar",
                                                                                   ifelse(grepl("lynx", model), "Lynx", NA)))) %>% factor(),
                                                    Sex = ifelse(grepl("_f", model), "Females",
                                                                 ifelse(grepl("_m", model), "Males", "All")) %>% factor())
displ_dist_road_df$species <- factor(displ_dist_road_df$species, levels=c("Roe deer", "Red deer", "Wild boar", "Lynx"))
displ_dist_road_df$species


##### Figure 3 ####

#### Road crossing (one plot per species)
displ_road_cross_ls <- split(displ_road_cross_df, displ_road_cross_df$species)
## ungulates
displ_road_cross_plots_ung <- purrr::map(displ_road_cross_ls[-4], function(X)
  ggplot(X, aes(x = Crossing, y = speed, colour = Sex, shape = Crossing)) +
    geom_pointrange(aes(ymin = lci, ymax = uci),
                    position = position_dodge(width = 0.5), 
                    linewidth = 1, size = 1) +
    labs(y = "Expected displacement [m/h]") +
    scale_colour_manual(values=c("#FC8D62", "#66C2A5")) +
    scale_shape_manual(values = c(1, 4)) +
    guides(shape = "none") +
    theme_bw() +
    theme(axis.text.x.bottom = element_text(size = 18),
          axis.text.y.left = element_text(size = 18),
          axis.text.x.top = element_blank(),
          axis.text.y.right = element_blank(),
          axis.title = element_text(size = 20, face = "bold"),
          axis.title.y = element_text(margin = margin(t = 0, r = 15, b = 0, l = 0)),
          axis.title.x = element_blank(),
          legend.title = element_text(size = 14, face = "bold"),
          legend.text = element_text(size = 12, margin = margin(t = 0, r = 0, b = 1, l = 0)),
          panel.grid.major.x = element_blank(),
          panel.grid.minor.y = element_blank(),
          panel.border = element_rect(linetype = "solid", fill=NA, linewidth=1))
)
displ_road_cross_plots_ung

## lynx
displ_road_cross_plots_lynx <- purrr::map(displ_road_cross_ls[4], function(X)
  ggplot(X, aes(x = Crossing, y = speed, shape = Crossing)) +
    geom_pointrange(aes(ymin = lci, ymax = uci),
                    position = position_dodge(width = 0.5), 
                    linewidth = 1, size = 1, colour="#A0A0A0") +
    labs(y = "Expected displacement [m/h]") +
    scale_shape_manual(values = c(1, 4))+
    theme_bw() +
    theme(axis.text.x.bottom = element_text(size = 18),
          axis.text.y.left = element_text(size = 18),
          axis.text.x.top = element_blank(),
          axis.text.y.right = element_blank(),
          axis.title = element_text(size = 20, face = "bold"),
          axis.title.y = element_text(margin = margin(t = 0, r = 15, b = 0, l = 0)),
          axis.title.x = element_blank(),
          legend.title = element_text(size = 14, face = "bold"),
          legend.text = element_text(size = 12, margin = margin(t = 0, r = 0, b = 1, l = 0)),
          panel.grid.major.x = element_blank(),
          panel.grid.minor.y = element_blank(),
          panel.border = element_rect(linetype = "solid", fill=NA, linewidth=1))
)
displ_road_cross_plots_lynx

## adjust plots
displ_road_cross_plots <- list(roe_deer=displ_road_cross_plots_ung$`Roe deer`,
                               red_deer=displ_road_cross_plots_ung$`Red deer`,
                               wild_boar=displ_road_cross_plots_ung$`Wild boar`,
                               lynx=displ_road_cross_plots_lynx$Lynx)
## deer
displ_road_cross_plots_p_deer <- purrr::map(displ_road_cross_plots[c(1,2)], function(X)
  X +
    #ylim(50, 180) +
    scale_y_continuous(limits=c(50, 205), breaks=c(60, 120, 180), labels=c("60", "120", "180")) +
    theme(axis.title.y = element_blank(), axis.text.x.bottom = element_blank(),
          legend.title = element_blank(),
          legend.justification = "bottom"))
displ_road_cross_plots_p_deer
## boars
displ_road_cross_plots_p_boar <- purrr::map(displ_road_cross_plots[3], function(X)
  X +
    #ylim(30, 1210) +
    scale_y_continuous(limits=c(30, 1210), breaks=c(60, 480, 900), labels=c("60", "480", "900")) +
    theme(axis.title.y = element_blank(),axis.text.x.bottom = element_blank(),
          legend.title = element_blank(),
          legend.justification = "bottom"))
displ_road_cross_plots_p_boar
## lynx
displ_road_cross_plots_p_lynx <- purrr::map(displ_road_cross_plots[4], function(X)
  X +
    #ylim(30, 1210) +
    scale_y_continuous(limits=c(30, 1210), breaks=c(60, 480, 900), labels=c("60", "480", "900"))  +
    theme(axis.title.y = element_blank(),
          legend.position = "null"))
displ_road_cross_plots_p_lynx <- annotate_figure(
  ggarrange(plotlist = list(displ_road_cross_plots_p_lynx[[1]]),
            ncol = 2, nrow = 1, common.legend = F, widths = c(1, 0.40)))
displ_road_cross_plots_p_lynx
## all-in-one
displ_road_cross_plots_all <- annotate_figure(
  ggarrange(plotlist = list(displ_road_cross_plots_p_deer[[1]],
                            displ_road_cross_plots_p_deer[[2]],
                            displ_road_cross_plots_p_boar[[1]],
                            displ_road_cross_plots_p_lynx),
            ncol = 1, nrow = 4, common.legend = F, heights = c(8.5, 8.5, 8.5, 10)),
  bottom = text_grob("Road Crossing", size = 20, vjust=0.3, hjust=0.7, face="bold"))

displ_road_cross_plots_all



#### Distance to roads (one plot per species)
displ_dist_road_ls <- split(displ_dist_road_df, displ_dist_road_df$species)

## ungulates
displ_dist_road_df_plots_ung <- purrr::map(displ_dist_road_ls[-4], function(X)
  ggplot(X, aes(x = dist.road, y = speed, fill = Sex)) +
  geom_ribbon(aes(ymin = lci, ymax = uci), alpha = 0.5) +
  geom_line(size = 1, aes(x = dist.road, y = speed, colour = Sex)) +
  labs(y = "Expected displacement [m/h]", x = "Distance to Road [m]") +
  scale_fill_manual(values=c("#FC8D62", "#66C2A5")) +
  scale_colour_manual(values=c("#FC8D62", "#66C2A5")) +
  theme_bw() +
  theme(axis.text.x = element_text(size = 18, face = "bold", vjust=0.5),
        axis.text.y = element_text(size = 18),
        axis.title = element_text(size = 20, face = "bold"),
        axis.title.y = element_text(margin = margin(t = 0, r = 15, b = 0, l = 0)),
        axis.title.x = element_text(margin = margin(t = 0, r = 15, b = 0, l = 0), vjust=-2),
        plot.title = element_text(hjust = 0.5, size = 16, face = "bold",margin = margin(t = 0, r = 0, b = 15, l = 0)),
        legend.title = element_text(size = 14, face = "bold"),
        legend.text = element_text(size = 13, margin = margin(t = 0, r = 0, b = 5, l = 0)),
        panel.grid.major.x = element_blank(), panel.grid.minor.x = element_blank(), panel.grid.minor.y = element_blank(),
        panel.border = element_rect(linetype = "solid", fill=NA, linewidth=1))
  )
displ_dist_road_df_plots_ung

## lynx
displ_dist_road_df_plots_lynx <- purrr::map(displ_dist_road_ls[4], function(X)
  ggplot(X, aes(x = dist.road, y = speed)) +
    geom_ribbon(aes(ymin = lci, ymax = uci), alpha = 0.5, colour="#A0A0A0") +
    geom_line(size = 1, aes(x = dist.road, y = speed), colour="#606060") +
    labs(y = "Expected displacement [m/h]", x = "Distance to Road [m]") +
    theme_bw() +
    theme(axis.text.x = element_text(size = 18),
          axis.text.y = element_text(size = 18),
          axis.title = element_text(size = 20,face = "bold"),
          axis.title.y = element_text(margin = margin(t = 0, r = 15, b = 0, l = 0)),
          axis.title.x = element_text(margin = margin(t = 0, r = 15, b = 0, l = 0), vjust=-2),
          plot.title = element_text(hjust = 0.5, size = 16, face = "bold",margin = margin(t = 0, r = 0, b = 15, l = 0)),
          panel.grid.major.x = element_blank(), panel.grid.minor.x = element_blank(), panel.grid.minor.y = element_blank(),
          panel.border = element_rect(linetype = "solid", fill=NA, linewidth=1))
)
displ_dist_road_df_plots_lynx

## adjust plots
displ_dist_road_plots <- list(roe_deer=displ_dist_road_df_plots_ung$`Roe deer`,
                               red_deer=displ_dist_road_df_plots_ung$`Red deer`,
                               wild_boar=displ_dist_road_df_plots_ung$`Wild boar`,
                               lynx=displ_dist_road_df_plots_lynx$Lynx)
# deer
displ_dist_road_plots_p_deer <- purrr::map(displ_dist_road_plots[c(1:2)], function(X)
  X +
    #xlim(0, 5711) +
    scale_x_continuous(limits=c(0, 5711), breaks=c(0, 2500, 5000), labels=c("0", "2500", "5000")) +
    #ylim(50, 205) +
    scale_y_continuous(limits=c(50, 205), breaks=c(60, 120, 180), labels=c("60", "120", "180")) +
    theme(axis.title.y = element_blank(), axis.title.x = element_blank(),
          axis.text.x.bottom = element_blank(), axis.ticks.x = element_blank(),
          legend.position = "null"))
displ_dist_road_plots_p_deer
# boars
displ_dist_road_plots_p_boar <- purrr::map(displ_dist_road_plots[3], function(X)
  X +
    #xlim(0, 5711) +
    scale_x_continuous(limits=c(0, 5711), breaks=c(0, 2500, 5000), labels=c("0", "2500", "5000")) +
    #ylim(50, 205) +
    scale_y_continuous(limits=c(50, 205), breaks=c(60, 120, 180), labels=c("60", "120", "180")) +
    theme(axis.title.y = element_blank(), axis.title.x = element_blank(),
          axis.text.x.bottom = element_blank(), axis.ticks.x = element_blank(),
          legend.position = "null"))
displ_dist_road_plots_p_boar
# lynx
displ_dist_road_plots_lynx <- purrr::map(displ_dist_road_plots[4], function(X)
  X +
    #xlim(0, 5711) +
    scale_x_continuous(limits=c(0, 5711), breaks=c(0, 2500, 5000), labels=c("0", "2500", "5000")) +
    #ylim(300, 900) +
    scale_y_continuous(limits=c(30, 1210), breaks=c(60, 480, 900), labels=c("60", "480", "900")) +
    theme(axis.title.y = element_blank(), axis.title.x = element_blank(),
          legend.position = "null"))
displ_dist_road_plots_lynx

## all-in-one
displ_dist_road_plots_all <- annotate_figure(
  ggarrange(plotlist = list(displ_dist_road_plots_p_deer[[1]],
                            displ_dist_road_plots_p_deer[[2]],
                            displ_dist_road_plots_p_boar[[1]],
                            displ_dist_road_plots_lynx[[1]]),
            ncol = 1, nrow = 4, common.legend = F, heights = c(8.5, 8.5, 8.5, 10)),
  left = text_grob("Expected displacement [m/h]", rot = 90, size = 20, vjust=0.3, face="bold"),
  bottom = text_grob("Distance to Road [m]", size = 20, vjust=0.3, hjust=0.4, face="bold"))

displ_dist_road_plots_all


#### Figure 3
fig_3 <- annotate_figure(
  ggarrange(plotlist = list(displ_dist_road_plots_all,
                            displ_road_cross_plots_all),
            ncol = 2, nrow = 1, common.legend = F, widths = c(8, 10))) +
  add_phylopic(roe.img, x=0.92, y=0.93, ysize=0.07, alpha=0.8) +
  add_phylopic(red.img, x=0.92, y=0.7, ysize=0.09, alpha=0.8) +
  add_phylopic(boar.img, x=0.92, y=0.45, ysize=0.05, alpha=0.8) +
  add_phylopic(lynx.img, x=0.92, y=0.2, ysize=0.065, alpha=0.8)

# ggsave(filename="fig_3.tiff", plot=fig_3, device="tiff", 
#        width=20, heigh=20, units="cm", dpi=300,
#        path=data_path, bg="white")
