#### Manuscript: OIK-10433
#### Title: Risk response towards roads is consistent across multiple species
##          in a temperate forest ecosystem
#### Date (creation): 12/2023
#### Date (last update): 01/2024
#### Purpose: Create coefficient and relative selection strength plots (Figure 4, 5)


#### Load packages ####

library(dplyr)
library(ggplot2)
library(glmmTMB) # version 1.1.2.3
library(broom)
library(broom.mixed)
library(RColorBrewer)
library(ggpubr)
library(rphylopic) 


#### Load data ####

data_path <- " " #add the path to your data (e.g. "C:/Users/username/Downloads/")

## Load models
lynxmodel_1h <- readRDS(paste0(data_path, "model_lynx_1h.rds"))
boarfemalemodel <- readRDS(paste0(data_path, "model_boar_female.rds"))
boarmalemodel <- readRDS(paste0(data_path, "model_boar_male.rds"))
roefemalemodel <- readRDS(paste0(data_path, "model_roe_female.rds"))
roemalemodel <- readRDS(paste0(data_path, "model_roe_male.rds"))
redfemalemodel <- readRDS(paste0(data_path, "model_red_female.rds"))
redmalemodel <- readRDS(paste0(data_path, "model_red_male.rds"))
## Create model list
model_ls <- list(roemalemodel=roemalemodel, roefemalemodel=roefemalemodel,
                 redmalemodel=redmalemodel, redfemalemodel=redfemalemodel,
                 boarmalemodel=boarmalemodel, boarfemalemodel=boarfemalemodel,
                 lynxmodel_1h=lynxmodel_1h)

## Get silhouettes with package 'rphylopic' to add later on arranged plots
pick_phylopic(name = "Sus scrofa", n = 5, view = 5)
boar.img <- get_phylopic(uuid = "87047da1-b40e-4b31-8492-4db262f129f5")
roe.img <- get_phylopic(uuid = get_uuid(name="Capreolus capreolus", n=1))
pick_phylopic(name = "Cervus elaphus", n = 2, view = 2)
red.img <- get_phylopic(uuid = "cc03f5c2-933f-4c40-9c64-7f8727556fdb")
pick_phylopic(name = "Lynx lynx", n = 4, view = 4)
lynx.img <- get_phylopic(uuid = "27a2173a-5903-46fc-83c5-29ed7f421046")
# get sex symbol
female = intToUtf8(9792)
male = intToUtf8(9794)


#### TIDY TABLES ####

lynx_tidy <- broom.mixed::tidy(lynxmodel_1h, effects = "fixed", conf.int=TRUE)
lynx_tidy$model <- "All"
boarfemale_tidy <- broom.mixed::tidy(boarfemalemodel, effects = "fixed", conf.int=TRUE)
boarfemale_tidy$model <- "Females"
boarmale_tidy <- broom.mixed::tidy(boarmalemodel, effects = "fixed", conf.int=TRUE)
boarmale_tidy$model <- "Males"
roefemale_tidy <- broom.mixed::tidy(roefemalemodel, effects = "fixed", conf.int=TRUE)
roefemale_tidy$model <- "Females"
roemale_tidy <- broom.mixed::tidy(roemalemodel, effects = "fixed", conf.int=TRUE)
roemale_tidy$model <- "Males"
redmale_tidy <- broom.mixed::tidy(redmalemodel, effects = "fixed", conf.int=TRUE)
redmale_tidy$model <- "Males"
redfemale_tidy <- broom.mixed::tidy(redfemalemodel, effects = "fixed", conf.int=FALSE) #conf.int=TRUE caused memory failure (calculate conf.int separately)
redfemale_tidy$model <- "Females"
redfemale_confint <- confint(redfemalemodel, component = "cond")
redfemale_confint_df <- as.data.frame(redfemale_confint[c(1:30),c(1,2)])
names(redfemale_confint_df) <- c("conf.low", "conf.high")
redfemale_tidy <- cbind(redfemale_tidy, redfemale_confint_df)
redfemale_tidy <- redfemale_tidy %>% as_tibble() %>% relocate(model, .after=conf.high)

## Bind data for plotting
# roe deer
roe_tidy <- rbind(roefemale_tidy, roemale_tidy)
roe_tidy <- roe_tidy %>% select(-c(effect, component))
roe_tidy$model <- factor(roe_tidy$model, levels=c('Females', 'Males'))
roe_tidy <- roe_tidy %>% mutate(exp_coef = exp(estimate))
roevarnum <- data.frame( term = factor(c(unique(roe_tidy$term))), variable_nr = c(1:length(unique(roe_tidy$term))))
roe_tidy <- merge(roe_tidy, roevarnum, by = "term")                        
roe_tidy <- roe_tidy %>% mutate(species="Roe deer")
# red deer
red_tidy <- rbind(redfemale_tidy, redmale_tidy)
red_tidy <- red_tidy %>% select(-c(effect, component))
red_tidy$model <- factor(red_tidy$model, levels=c('Females', 'Males'))
red_tidy <- red_tidy %>% mutate(exp_coef = exp(estimate))
redvarnum <- data.frame( term = factor(c(unique(red_tidy$term))), variable_nr = c(1:length(unique(red_tidy$term))))
red_tidy <- merge(red_tidy, redvarnum, by = "term")                        
red_tidy <- red_tidy %>% mutate(species="Red deer")
# wild boar
boar_tidy <- rbind(boarfemale_tidy, boarmale_tidy)
boar_tidy <- boar_tidy %>% select(-c(effect, component))
boar_tidy$model <- factor(boar_tidy$model, levels=c('Females', 'Males'))
boar_tidy <- boar_tidy %>% mutate(exp_coef = exp(estimate))
boarvarnum <- data.frame( term = factor(c(unique(boar_tidy$term))), variable_nr = c(1:length(unique(boar_tidy$term))))
boar_tidy <- merge(boar_tidy, boarvarnum, by = "term")                        
boar_tidy <- boar_tidy %>% mutate(species="Wild boar")
# lynx
lynx_tidy <- lynx_tidy %>% dplyr::select(-c(effect, component))
lynx_tidy <- lynx_tidy %>% mutate(exp_coef = exp(estimate))
lynxvarnum <- data.frame( term = factor(c(unique(lynx_tidy$term))), variable_nr = c(1:length(unique(lynx_tidy$term))))
lynx_tidy <- merge(lynx_tidy, lynxvarnum, by = "term")                        
lynx_tidy <- lynx_tidy %>% mutate(species="Lynx")

all_species_tidy <- rbind(roe_tidy, red_tidy, boar_tidy, lynx_tidy)
View(all_species_tidy)


#### FIGURE 4 ####

all_species_tidy_ha <- all_species_tidy %>% select(-variable_nr)

all_species_tidy_ha <- all_species_tidy_ha %>% filter(term %in% c("crossings:cover_end", "crossings:understory_end",
                                                                  "cover_end:log_dist_road_start", "understory_end:log_dist_road_start"))

varnum_all_species_ha <- data.frame( term = factor(c(unique(all_species_tidy_ha$term))), variable_nr = c(1:length(unique(all_species_tidy_ha$term))))
all_species_tidy_ha <- merge(all_species_tidy_ha, varnum_all_species_ha, by = "term")                        

all_species_tidy_ha <- all_species_tidy_ha %>% mutate(variable_nr = ifelse(term=="crossings:cover_end", 1,
                                                                           ifelse(term=="crossings:understory_end", 2,
                                                                                  ifelse(term=="cover_end:log_dist_road_start", 3,
                                                                                         ifelse(term=="understory_end:log_dist_road_start", 4, variable_nr)))))

all_species_tidy_ha$species <- factor(all_species_tidy_ha$species, levels=c("Roe deer", "Red deer", "Wild boar", "Lynx"))
all_species_tidy_ha$species

all_species_tidy_ha <- all_species_tidy_ha %>% rename(Sex=model)

##### Fig. 4a ####

fig_4a <- all_species_tidy_ha %>% filter(grepl("dist_road", term)) %>% 
  ggplot(aes(x = variable_nr, y = estimate, colour = species, pch = Sex)) +
  geom_pointrange(aes(ymin = conf.low, ymax = conf.high),
                  position = position_dodge(width = 0.7), linewidth = 1, size = 1) +
  geom_hline(yintercept = 0, lty = 2) +
  labs(y = "log-RSS") +
  labs(col = "Species") +
  scale_color_manual(values=c("#66C2A5", "#FC8D62", "#8DA0CB","#727D71")) + # or instead of the last one: #CF9963
  guides(colour=guide_legend(order=1), pch=guide_legend(order=2)) +
  #scale_y_continuous(limits=c(-0.155, 0.075), breaks=c(-0.10, 0, 0.10), labels=c("-0.10", "0", "0.10")) +
  
  scale_x_continuous(breaks = c(3,4),
                     labels = c("Distance to Road (ln) 
:Canopy Cover", 
                                "Distance to Road (ln) 
:Understorey")
  ) +
  theme_bw() +
  theme(axis.text.x = element_text(size = 16, face = "bold"),
        axis.text.y = element_text(size = 18),
        axis.title = element_text(size = 20,face = "bold"),
        axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 0)),
        axis.title.x=element_blank(),
        plot.title = element_text(hjust = 0.5, size = 16, face = "bold",margin = margin(t = 0, r = 0, b = 15, l = 0)),
        legend.title = element_text(size = 16, face = "bold"),
        legend.text = element_text(size = 14, margin = margin(t = 0, r = 0, b = 5, l = 0)),
        legend.spacing = unit(0.7, "cm"), legend.key.size=unit(0.8, "cm"), legend.key.width= unit(0.5, 'cm'),
        panel.grid.major.x = element_blank(), panel.grid.minor.x = element_blank(), panel.grid.minor.y = element_blank(),
        panel.border = element_rect(linetype = "solid", fill=NA, linewidth=1))
fig_4a


##### Fig. 4b ####

fig_4b <- all_species_tidy_ha %>% filter(!grepl("dist_road", term)) %>% 
  ggplot(aes(x = variable_nr, y = estimate, colour = species, pch = Sex)) +
  geom_pointrange(aes(ymin = conf.low, ymax = conf.high),
                  position = position_dodge(width = 0.7), linewidth = 1, size = 1) +
  geom_hline(yintercept = 0, lty = 2) +
  labs(y = "log-RSS") +
  labs(col = "Species") +
  scale_color_manual(values=c("#66C2A5", "#FC8D62", "#8DA0CB","#727D71")) + # or instead of the last one: #CF9963
  guides(colour=guide_legend(order=1), pch=guide_legend(order=2)) +
  #scale_y_continuous(limits=c(-0.84, 1.4), breaks=c(-1, 0, 1), labels=c("-1", "0", "1")) +
  scale_x_continuous(breaks = c(1,2),
                     labels = c("Road Crossing 
:Canopy Cover", 
                                "Road Crossing 
:Understorey")
  ) +
  theme_bw() +
  theme(axis.text.x = element_text(size = 16, face = "bold"),
        axis.text.y = element_text(size = 18),
        axis.title = element_text(size = 20,face = "bold"),
        axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 0)),
        axis.title.x=element_blank(),
        plot.title = element_text(hjust = 0.5, size = 16, face = "bold",margin = margin(t = 0, r = 0, b = 15, l = 0)),
        legend.title = element_text(size = 16, face = "bold"),
        legend.text = element_text(size = 14, margin = margin(t = 0, r = 0, b = 5, l = 0)),
        legend.spacing = unit(0.7, "cm"), legend.key.size=unit(0.8, "cm"), legend.key.width= unit(0.5, 'cm'),
        panel.grid.major.x = element_blank(), panel.grid.minor.x = element_blank(), panel.grid.minor.y = element_blank(),
        panel.border = element_rect(linetype = "solid", fill=NA, linewidth=1)) #+
  #ylim(-0.9, 0.9)
fig_4b

#get legend
fig_4_leg <- get_legend(fig_4b + theme(legend.title = element_text(size=18, face="bold"),
                                       legend.title.align=0.5,
                                       legend.text = element_text(size = 16, margin = margin(t = 3)),
                                       legend.key.size=unit(0.5, "cm"), legend.key.width= unit(0.5, 'cm'),
                                       legend.direction = "vertical",
                                       legend.box = "horizontal", legend.box.margin=margin(b=20, r=-70),
                                       legend.spacing = unit(2, "cm")) +
                          guides(colour=guide_legend(order=1, nrow=2, byrow=TRUE),
                                 pch=guide_legend(order=2, direction="vertical",
                                                  title.position="top")))


##### Fig. 4a/4b ####
fig_4 <-   annotate_figure(ggarrange(plotlist = list(fig_4a, NULL, fig_4b),
                                     ncol = 1, nrow = 3, heights = c(1, 0.1, 1), align="hv",
                                     common.legend = T, legend="top", legend.grob=fig_4_leg,
                                     labels=c("(a)", "", "(b)"), font.label=list(size=20), vjust = c(1, 1))) 
fig_4

# ggsave(filename="fig_4.tiff", plot=fig_4, device="tiff", 
#        width=20, heigh=25, units="cm", dpi=300,
#        path=data_path, bg="white")


#### LOG-RSS ####

##### Load functions ####

## The following functions will be called within one another to calculate the relative selection strength (log-rss)
# Only predictions for 'Distance to roads : Time of Day' are showed in this script,
# but the functions have been generalized to calculate the log-rss in different spatial and temporal conditions


#### Function to transform factor variables to numeric
fac_to_num <- function(x){
  for (i in 1:length(x)) {
    if (is.factor(x[,i])) {
      x[,i] <- as.numeric(as.character(x[,i])) 
    }
  }
  return(x)
}


#### Function to transform factor variables to characters
fac_to_char <- function(x){
  for (i in 1:length(x)) {
    if (is.factor(x[,i])) {
      x[,i] <- as.character(x[,i])
    }
  }
  return(x)
}


#### Function to transform variables with a certain number of levels from numeric to integers
num_to_int <- function(x, length){
  for (i in 1:length(x)) {
    if (length(unique(x[,i]))==length) {
      x[,i] <- as.integer(x[,i]) 
    }
  }
  return(x)
}


#### Function to prepare the two new datasets
get_mvals <- function(dataset, var = NULL, vals = NULL){
  
  ## transform numeric variables to integers if of length 2
  # so that the most frequent value from variables crossings, time of day and season can be picked
  dataset <- num_to_int(dataset, 2)
  ## back-transform y to factor as we want it to be 1 (if treated as integer, the most often occurring value will be picked, which is 0 for random steps)
  dataset$y <- as.factor(dataset$y)
  ## do transform id to factor so it will be treated as id_step_id (it will get the first id appearing in the dataset)
  # if the most recurrent id is to be chosen, then id should be transformed to integer (see below)
  dataset$id <- as.factor(dataset$id)
  
  ## save the class of each variable
  varclass <- dataset %>%
    dplyr::summarise_all(class) %>% 
    tidyr::gather(variable, class) 
  
  ## create a dataset per each class
  numvars <- varclass %>% filter(class %in% c("numeric", "matrix")) %>%  dplyr::select(variable) %>% unique
  catvars <- varclass %>% filter(class %in% c("character")) %>%  dplyr::select(variable) %>% unique
  intvars <- varclass %>% filter(class == "integer") %>%  dplyr::select(variable) %>% unique
  facvars <- varclass %>% filter(class %in% c("factor")) %>%  dplyr::select(variable) %>% unique
  
  ## get the mean of each numeric variable and save as data frame 
  # variables considered numeric in the function are: sl, log_sl, cos_ta, log_dist_road, cover, understory, ruggedness
  nummean <- dataset %>%  dplyr::select(numvars$variable) %>% summarise_all(mean) %>% as.data.frame()
  
  ## get the value of integer variables with the highest number of observations (i.e. most occurring value) and transform to numeric
  # variables considered integers in the function are: crossings, night, twilight, season
  foo <- function(x){
    as.numeric(names(which.max(table(x))))
  }
  
  ints <- as.data.frame(t(apply(dataset %>%  dplyr::select(intvars$variable), 2, foo)))
  
  ## get the first value appearing in the dataset for factors and character variables
  # variables considered factors in the function are: y, id
  # variables considered characters in the function are: id_step_id
  # then transform to numeric as in the original dataset used in the model
  foo_fac <- function(x){
    ff <- as.factor(t(x))
    ff[1]
  }
  
  facs <-  dataset %>%  dplyr::select(facvars$variable) %>% group_by() %>% summarise(across(where(is.factor),foo_fac)) %>% as.data.frame() %>% fac_to_num()
  
  ## get the first value appearing for character variables and create a dataset with variables of all classes
  if(length(catvars$variable)!=0){
    chars  <- dataset %>%  dplyr::select(catvars$variable) %>% group_by() %>% summarise(across(where(is.character),foo_fac)) %>% as.data.frame() %>% fac_to_char()
    m <- cbind(nummean, ints, facs, chars)
  } else{
    m <- cbind(nummean, ints, facs)
  }
  
  ## if var is null, just return m, which will have only one value per variable (e.g. the mean for numeric variables)
  # if var is not null, save m (one value per variable so far) in another object mdat and check if length of values is greater than 1,
  # if yes, do rbind m and mdat for 99 times (for a total of 100 rows), then change the values of var as set from the argument "var" and return m
  if(!is.null(var)){
    mdat <- m
    if(length(vals)> 1){
      for(i in 1:(length(vals)-1)){
        mdat <- rbind(mdat,m) 
      }
    }
    mdat[,var] <- vals
    m <- mdat
  }	
  
  ## force time of day to be day (same throughout all groups for more comparable results)
  # I anyways consider all times of day in Fig. 5a so all scenarios will be displayed
  m$night_suncalc_start <-0
  m$night_suncalc_end <-0
  
  ## add controls on impossible times of day
  # Warnings
  if(unique(m$night_suncalc_end)!=unique(m$night_suncalc_start)) warning("Start and end step have different time of day, set them at the same time")
  if(unique(m$twilight_suncalc_end)!=unique(m$twilight_suncalc_start)) warning("Start and end step have different time of day, set them at the same time")
  if(unique(m$y)!=1) warning("y=0, set it to 1")
  # Errors
  if(unique(m$night_suncalc_end)==1 & unique(m$twilight_suncalc_end==1)) stop("Impossible time of day: night and twilight are both equal to 1")
  if(unique(m$night_suncalc_start)==1 & unique(m$twilight_suncalc_start==1)) stop("Impossible time of day: night and twilight are both equal to 1")
  
  return(m)	
}


#### Function to calculate relative selection strength (with optional confidence intervals)
## see: https://rdrr.io/cran/amt/src/R/log_rss.R
get_logrss <- function(model, var = NULL, vals = NULL, ci = TRUE, ci_level = 0.95, var2 = NULL, vals2 = NULL , valref = NULL){
  
  ## prepare s1 dataset with all constant variables (e.g. mean for numeric variables) except for one ('var') which will get new variables from 'vals'
  #  if also var2 and vals2 are true, another variable ('var2') will be not constant but will take values from 'vals2', to display interaction terms
  s1 <- get_mvals(model$frame, var = var, vals = vals)
  
  ## prepare s2 dataset with only one row, all variables have the same value as in s1 except for 'var' (and 'var2' if declared), which will have now only one value (e.g. the mean)
  s2 <- get_mvals(model$frame)
  
  ## make sure that the mean value of s2 is also included in s1 and sort s1 from lower to higher value
  s1 <- rbind(s2,s1)
  s1[,var] <- sort(s1[,var])
  
  ## if user declared a var2, change var2 current constant values to the values given in vals2
  # note that var2 can only take one value per dataset, therefore 2 different data frames will need to be created (pp1 and pp2 in function 'modeleffects_withVar()' below)
  # if valref is not null, it will replace var2 from data frame s2, needed to create second data frame "pp2" without changing the reference value of s2 (see function 'modeleffects_withVar()' below))
  if(!is.null(var2)){
    s1[var2] <- vals2
    s2[var2] <- vals2
    if(!is.null(valref)){
      s2[var2] <- valref
    }
  }

  ## Calculate model predictions and split it into predictions for s1 and predictions for s2
  pred_x1 <- predict(model, newdata = data.frame(rbind(s1,s2)),
                     type = "link", se.fit = FALSE, allow.new.levels=TRUE)
  y_x1 <- pred_x1[1:nrow(s1)]
  y_x2 <- pred_x1[nrow(s1) + 1]
  
  ## Calculate log_rss and make data frame to use for plots
  log_rss_ <- unname(y_x1 - y_x2)
  df <- data.frame(log_rss = log_rss_, s1)
  
  ## calculate confidence intervals if requested 
  if (ci!=FALSE){
    ## Large-sample based standard error method
    # Get model terms (same as predict.lm), discard response variable
    Terms <- stats::delete.response(terms(model))
    # Get model matrix for x1 and x2 (model.matrix expands factors to a set of dummy variables and interactions similarly)
    x1_mm <- stats::model.matrix(Terms, data = s1)
    x2_mm <- stats::model.matrix(Terms, data = s2)
    # Get model variance-covariance matrix
    m_vcov <- stats::vcov(model)
    # Subtract x2 model matrix from each row of x1, results will be always zero since s1 and s2 have the same values, except for 'var' (and 'var2' if exists)
    delta_mm <- sweep(data.matrix(x1_mm), 2, data.matrix(x2_mm))
    # Get variance of log-RSS prediction (diag extracts the diagonal matrix)
    var_pred <- diag(delta_mm %*% m_vcov[[1]] %*% t(delta_mm))
    # Get standard error of prediction
    logrss_se <- unname(sqrt(var_pred))
    # Get critical value depending on conf int level requested (default is 0.95)
    p <- 1 - ((1 - ci_level)/2)
    zstar <- qnorm(p)
    # Compute bounds
    df$lwr <- df$log_rss - zstar * logrss_se
    df$upr <- df$log_rss + zstar * logrss_se
  }
  
  ## add the name of the model at the end of the dataframe
  df <- df %>% mutate(model = ifelse(model$call$data=="roetrk_ssf_f", "roe_deer_females",
                                                   ifelse(model$call$data=="roetrk_ssf_m", "roe_deer_males",
                                                          ifelse(model$call$data=="redtrk_ssf_f", "red_deer_females",
                                                                 ifelse(model$call$data=="redtrk_ssf_m", "red_deer_males",
                                                                        ifelse(model$call$data=="boartrk_ssf_f", "wild_boar_females",
                                                                               ifelse(model$call$data=="boartrk_ssf_m", "wild_boar_males",
                                                                                      ifelse(model$call$data=="lynxtrk_ssf", "lynx", NA))))))))

  return(df)
  
}


#### function to prepare dataset to plot log_rss
modeleffects_withVar <- function(model, var = NULL, vals = NULL, ci = TRUE, ci_level = 0.95, var2 = NULL, vals2 = NULL,
                                      rescale = FALSE, vals_char = NULL, yl = NULL, xl = NULL){
  
  ## Get log_rss, if var2 is not null, pp1 and pp2 will be identical except for 'var2', which will take values, i.e. vals2[1] for pp1 and vals2[2] for pp2
  # then add var1 and var2 columns to keep it with a general name based on user's input so the next steps of the function keep on using "var1" and "var2"
  pp1 <- get_logrss(model, var, vals , ci = ci, var2 = var2, vals2 = vals2[1])
  pp1$var1 <- pp1[,var]
  pp1$var2 <- pp1[,var2]
  # for the second data frame, valref is not null and it will replace the last value of var2 (s2) in the prediction (not in the final dataset)
  pp2 <- get_logrss(model, var, vals , ci = ci, var2 = var2, vals2 = vals2[2], valref = vals2[1])
  pp2$var1 <- pp2[,var]
  pp2$var2 <- pp2[,var2]
  
  pp <- rbind(pp1,pp2)
  
  ## unscale if requested (i.e. if rescale=TRUE)
  if(rescale){
    pp$var1 <- attr(model$frame[,var], "scaled:scale")*pp$var1 + attr(model$frame[,var], "scaled:center")
  }	
  
  return(pp)
  
}


#### Function to create predictions for day, night and twilight to plot
## takes as input the model list and the variable of interest
modeleffects_tod <- function(model_list, var=NULL) {
  
  # create data frames to plot with function modeleffects_withVar() applied to each model in model_list
  night_dfls <- purrr::map(model_list, function(X) {
    modeleffects_withVar(X, var = var, vals = seq(from=min(X$frame[,var]), to=max(X$frame[,var]), length.out=100),
                              ci=TRUE, ci_level = 0.95, var2 = "night_suncalc_end", vals2 = c(0,1),
                              rescale = TRUE) })
  
  twilight_dfls <- purrr::map(model_list, function(X) {
    modeleffects_withVar(X, var = var, vals = seq(from=min(X$frame[,var]), to=max(X$frame[,var]), length.out=100),
                              ci=TRUE, ci_level = 0.95, var2 = "twilight_suncalc_end", vals2 = c(0,1),
                              rescale = TRUE)})
  
  ## edit column var2 of each just created data frames to specify time of the day (day will only appear once)  
  night_dfls <- night_dfls %>% purrr::map(., function(x) mutate(x, var2 = ifelse(var2==0, "day", "night") %>% factor()))
  twilight_dfls <- twilight_dfls %>% purrr::map(., function(x) mutate(x, var2 = ifelse(var2==0, "day", "twilight") %>% factor()) %>% filter(var2=="twilight"))
  
  ## rbind day/night and twilight data frames of each model to create unique data frames (one per each model) of day/night/twilight
  tod_dfls <- list()
  for (i in 1:length(model_list)){
    tod_dfls[[i]] <- rbind(night_dfls[[i]], twilight_dfls[[i]])
    
  }
  
  return(tod_dfls)
  
}


#### Functions to plot datasets with calculated relative selection strength at different times of the day
## 3 different plot types can be chosen
plot_modeleffects_tod <- function(tod_dfls, model_list, var=NULL, type=1, back_tf=FALSE) {
  
  ## if var1 is a logarithm and back-transformation is needed
  if(back_tf){
    for(i in 1:length(model_list)) {
      tod_dfls[[i]]$var1 <- exp(tod_dfls[[i]]$var1)
    }
  }
  
  var_nice <- c("log_dist_road_end" = "Distance to Road (ln)", "crossings" = "Crossing", "cover_end" = "Canopy Cover",
                "understory_end" = "Understory", "ruggedness_end" ="Ruggedness", "log_dist_road_start" = "Distance to Road (ln)",
                "season_end" = "Season")
  
  # limit x axis to observations of var at each specific time of day (e.g. min and max distance to roads values during the day are slightly different than during twilight and night)
  # and create colors depending on the time of day
  tod_dfls_day <- list()
  tod_dfls_night <- list()
  tod_dfls_twilight <- list()
  tod_dfls_lim <- list()
  
  for(i in 1:length(tod_dfls)) {
  
    tod_dfls_day[[i]] <- tod_dfls[[i]] %>% filter(.$var2=="day") %>% 
      filter(.[, var] >= min(filter(model_list[[i]]$frame, night_suncalc_end==0 & twilight_suncalc_end==0)[, var]) &
               .[, var] <= max(filter(model_list[[i]]$frame, night_suncalc_end==0 & twilight_suncalc_end==0)[, var])) %>% 
      mutate(colors="#fdd49e")
    
    tod_dfls_night[[i]] <- tod_dfls[[i]] %>% filter(.$var2=="night") %>% 
      filter(.[, var] >= min(filter(model_list[[i]]$frame, night_suncalc_end==1 & twilight_suncalc_end==0)[, var]) &
               .[, var] <= max(filter(model_list[[i]]$frame, night_suncalc_end==1 & twilight_suncalc_end==0)[, var])) %>% 
      mutate(colors="#525252")
    
    tod_dfls_twilight[[i]] <- tod_dfls[[i]] %>% filter(.$var2=="twilight") %>% 
      filter(.[, var] >= min(filter(model_list[[i]]$frame, night_suncalc_end==0 & twilight_suncalc_end==1)[, var]) &
               .[, var] <= max(filter(model_list[[i]]$frame, night_suncalc_end==0 & twilight_suncalc_end==1)[, var])) %>% 
      mutate(colors="#8DA0CB")
    
    tod_dfls_lim[[i]] <- rbind(tod_dfls_day[[i]], tod_dfls_night[[i]], tod_dfls_twilight[[i]])
  }
  
  #### plot

  if(type==1){ # with colors, plot will be the same as if plot=TRUE in function modeleffects_tod()
    tod_plot <-  purrr::map(tod_dfls_lim, function(X)
      ggplot(X, aes(x = var1, y = log_rss, group = var2, fill = var2)) +
        geom_ribbon(aes(ymin = lwr, ymax = upr), alpha = 0.5) +
        geom_line(size = 1, aes(x = var1, y = log_rss, linetype = var2)) +
        geom_hline(yintercept = 0, linetype = "dashed", color = "gray30") +
        scale_fill_manual(name = "Time of Day", breaks = c(unique(X$var2)),
                          values = c(unique(X$colors)), labels = as.character(unique(X$var2)))+
        scale_linetype_manual(name = "Time of Day", breaks = c(unique(X$var2)), values=c(1,2,3), labels = as.character(unique(X$var2)))+
        xlab(var_nice[var]) +
        ylab(paste("log-RSS vs Mean",var_nice[var])) +
        #xlab("") + ylab("")+
        theme_light() +
        theme(text = element_text(size=10), axis.text = element_text(size=12), axis.title = element_text(size=14), 
              legend.text = element_text(size = 12), legend.title = element_text(size=14),
              panel.grid.major = element_blank(), panel.grid.minor = element_blank()))
    
  } else if(type==2){ # with colors, like Fig. 2 from Prokopenko et al. (2017)
    tod_plot <-  purrr::map(tod_dfls_lim, function(X)
      ggplot(X, aes(x = var1, y = log_rss, group = var2, fill = var2)) +
        geom_ribbon(aes(ymin = lwr, ymax = upr, colour=var2), linetype="dotted", size=0.8, fill=NA, show.legend = FALSE) +
        geom_line(size = 1.3, aes(x = var1, y = log_rss, colour=var2)) +
        geom_hline(yintercept = 0, linetype = "dashed", color = "gray30") +
        scale_color_manual(name = "Time of Day", breaks = c(unique(X$var2)),
                           values = c(unique(X$colors)), labels = as.character(unique(X$var2)))+
        xlab(var_nice[var]) +
        ylab(paste("log-RSS vs Mean",var_nice[var])) +
        #xlab("") + ylab("")+
        theme_light() +
        theme(text = element_text(size=10), axis.text = element_text(size=12), axis.title = element_text(size=14), 
              legend.text = element_text(size = 12), legend.title = element_text(size=14),
              panel.grid.major = element_blank(), panel.grid.minor = element_blank()))
    
  } else if(type==3){ # black and white, like Fig.2 from Passoni et al. (2021)
    tod_plot <-  purrr::map(tod_dfls_lim, function(X)
      ggplot(X, aes(x = var1, y = log_rss, group = var2, fill = var2)) +
        geom_ribbon(aes(ymin = lwr, ymax = upr, linetype = var2), color = "black", alpha = 0.25, fill="gray30") +
        geom_line(size = 1, aes(x = var1, y = log_rss, linetype = var2)) +
        geom_hline(yintercept = 0, linetype = "dashed", color = "gray30") +
        scale_linetype_manual(name = "Time of Day", breaks = c(unique(X$var2)), values=c(1,2,3), labels = as.character(unique(X$var2)))+
        xlab(var_nice[var]) +
        ylab(paste("log-RSS vs Mean",var_nice[var])) +
        #xlab("") + ylab("")+
        theme_light() +
        theme(text = element_text(size=10), axis.text = element_text(size=12), axis.title = element_text(size=14), 
              legend.text = element_text(size = 12), legend.title = element_text(size=14),
              panel.grid.major = element_blank(), panel.grid.minor = element_blank()))
  }
  
}


##### Predictions ####

## Distance to Road : Time of Day
system.time(
  dist_road_tod <- modeleffects_tod(model_ls, var = "log_dist_road_end")
)#~40 min

## check summary of predictions
summary(dist_road_tod[[1]])
summary(dist_road_tod[[2]])
summary(dist_road_tod[[3]])
summary(dist_road_tod[[4]])
summary(dist_road_tod[[5]])
summary(dist_road_tod[[6]])
summary(dist_road_tod[[7]])

# check that time of day is set correctly, i.e.:
# - when var2=day, night=0 and twilight=0
# - when var2=night, night=1 and twilight=0)
# - when var2=twilight, night=0 and twilight=1)
dist_road_tod %>% bind_rows() %>% group_by(var2, night_suncalc_end, twilight_suncalc_end) %>% summarise(n=n())

View(dist_road_tod[[1]])
View(dist_road_tod[[2]])
View(dist_road_tod[[3]])
View(dist_road_tod[[4]])
View(dist_road_tod[[5]])
View(dist_road_tod[[6]])
View(dist_road_tod[[7]])


##### Plot predictions

## make plots
dist_road_tod_plots <- plot_modeleffects_tod(dist_road_tod, model_ls, var="log_dist_road_end", type=2, back_tf=TRUE)
dist_road_tod_plots

## check summary
summary(dist_road_tod_plots[[1]]$data)
summary(dist_road_tod_plots[[2]]$data)
summary(dist_road_tod_plots[[3]]$data)
summary(dist_road_tod_plots[[4]]$data)
summary(dist_road_tod_plots[[5]]$data)
summary(dist_road_tod_plots[[6]]$data)
summary(dist_road_tod_plots[[7]]$data)

## give names to each species and group
dist_road_tod_plots <- list(roe_deer_males=dist_road_tod_plots[[1]], roe_deer_females=dist_road_tod_plots[[2]],
                            red_deer_males=dist_road_tod_plots[[3]], red_deer_females=dist_road_tod_plots[[4]],
                            wild_boar_males=dist_road_tod_plots[[5]], wild_boar_females=dist_road_tod_plots[[6]],
                            lynx=dist_road_tod_plots[[7]])


#### FIGURE 5 ####

##### Fig. 5a) Distance to roads - Time of day ####

#### Edit plots and arrange them in a page

# get legend
tod_leg <- as_ggplot(get_legend(dist_road_tod_plots[[1]] +
                                  theme(legend.title = element_text(size=20, face="bold"),
                                        legend.text = element_text(size = 18, margin = margin(t = 3)),
                                        legend.key.size=unit(0.5, "cm"), legend.key.width= unit(1, 'cm'))))

## ungulates
# edit plots
dist_road_tod_p_ung <- purrr::map(dist_road_tod_plots[-7], function(X)
  X +
    #ylim(-20, 5) + # do use 'ylim(-80, 13)' to see the entire curves for females of all species 
    scale_y_continuous(limits=c(-20, 5), breaks=c(-20, -10, 0), labels=c("-20", "-10", "0")) +
    scale_x_continuous(trans = "log1p", breaks = c(0, 5, 25, 100, 500, 2500)) + 
    theme_bw() +
    theme(axis.title = element_blank(),
          legend.position = "null",
          axis.text.x = element_text(size = 18),
          axis.text.y = element_text(size = 18),
          panel.grid.major.x = element_blank(), panel.grid.minor.x = element_blank(), panel.grid.minor.y = element_blank(),
          panel.border = element_rect(linetype = "solid", fill=NA, linewidth=1)))
# arrange in a page
dist_road_tod_p_ung <- 
  annotate_figure(ggarrange(plotlist = list(dist_road_tod_p_ung[[2]], dist_road_tod_p_ung[[1]],
                                            dist_road_tod_p_ung[[4]], dist_road_tod_p_ung[[3]],
                                            dist_road_tod_p_ung[[6]], dist_road_tod_p_ung[[5]]),
                            ncol = 2, nrow = 3, common.legend = F, widths = c(1, 1, 1)))
dist_road_tod_p_ung

## lynx
# edit plots
dist_road_tod_p_lynx <- dist_road_tod_plots$lynx +
    #ylim(-20, 5) + # do use 'ylim(-80, 13)' to see the entire curves for females of all species 
    scale_y_continuous(limits=c(-10, 5), breaks=c(-10, -5, 0), labels=c("-10", "-5", "0")) +
    scale_x_continuous(trans = "log1p", breaks = c(0, 5, 25, 100, 500, 2500)) + 
    theme_bw() +
    theme(axis.title = element_blank(),
          legend.position = "null",
          axis.text.x = element_text(size = 18),
          axis.text.y = element_text(size = 18),
          panel.grid.major.x = element_blank(), panel.grid.minor.x = element_blank(), panel.grid.minor.y = element_blank(),
          panel.border = element_rect(linetype = "solid", fill=NA, linewidth=1))
dist_road_tod_p_lynx <- 
  annotate_figure(ggarrange(plotlist = list(dist_road_tod_p_lynx, tod_leg),
                            ncol = 2, nrow = 1, common.legend = F, heights = c(1, 1))) 
dist_road_tod_p_lynx

## arrange ungulates and lynx plots in a page

dist_road_tod_p_all <- 
  annotate_figure(ggarrange(plotlist = list(dist_road_tod_p_ung, dist_road_tod_p_lynx),
                            ncol = 1, nrow = 2, common.legend = F, heights = c(1, 0.35)),
                  left = text_grob("log-RSS", rot = 90, size = 20, vjust=0.5, face="bold"),
                  bottom = text_grob("Distance to Road [m]", size = 20, vjust=0.7, face="bold")) +
  add_phylopic(roe.img, x=0.42, y=0.835, ysize=0.05, alpha=0.8) +    # roe deer females
  annotate("text", x = 0.48, y = 0.835, label = female, size = 10) + # roe deer females
  add_phylopic(roe.img, x=0.9, y=0.835, ysize=0.05, alpha=0.8) +     # roe deer males
  annotate("text", x = 0.96, y = 0.835, label = male, size = 10) +   # roe deer males
  add_phylopic(red.img, x=0.42, y=0.595, ysize=0.06, alpha=0.8) +     # red deer females
  annotate("text", x = 0.48, y = 0.595, label = female, size = 10) +  # red deer females
  add_phylopic(red.img, x=0.9, y=0.595, ysize=0.06, alpha=0.8) +      # red deer males
  annotate("text", x = 0.96, y = 0.595, label = male, size = 10) +    # red deer males
  add_phylopic(boar.img, x=0.42, y=0.35, ysize=0.04, alpha=0.8) +    # wild boar females
  annotate("text", x = 0.48, y = 0.35, label = female, size = 10) +  # wild boar females
  add_phylopic(boar.img, x=0.9, y=0.35, ysize=0.04, alpha=0.8) +     # wild boar males
  annotate("text", x = 0.96, y = 0.35, label = male, size = 10) +    # wild boar males
  add_phylopic(lynx.img, x=0.42, y=0.10, ysize=0.05, alpha=0.8)     # lynx
dist_road_tod_p_all


##### Fig. 5b) Road crossing - Time of day ####

all_species_tidy_cross_tod <- all_species_tidy %>% select(-variable_nr)

all_species_tidy_cross_tod <- all_species_tidy_cross_tod %>% filter(term %in% c("crossings:night_suncalc_end", "crossings:twilight_suncalc_end"))

varnum_all_species_tidy_cross_tod <- data.frame( term = factor(c(unique(all_species_tidy_cross_tod$term))), variable_nr = c(1:length(unique(all_species_tidy_cross_tod$term))))
all_species_tidy_cross_tod <- merge(all_species_tidy_cross_tod, varnum_all_species_tidy_cross_tod, by = "term")                        

all_species_tidy_cross_tod <- all_species_tidy_cross_tod %>% mutate(variable_nr =  ifelse(term=="crossings:night_suncalc_end", 1,
                                                                                          ifelse(term=="crossings:twilight_suncalc_end", 2, variable_nr)))

all_species_tidy_cross_tod$species <- factor(all_species_tidy_cross_tod$species, levels=c("Roe deer", "Red deer", "Wild boar", "Lynx"))
all_species_tidy_cross_tod$species

all_species_tidy_cross_tod <- all_species_tidy_cross_tod %>% rename(Sex=model)

rcross_tod <-
  all_species_tidy_cross_tod %>% 
  ggplot(aes(x = variable_nr, y = estimate, colour = species, pch = Sex)) +
  geom_pointrange(aes(ymin = conf.low, ymax = conf.high),
                  position = position_dodge(width = 0.7), linewidth = 1, size = 1) +
  geom_hline(yintercept = 0, lty = 2) +
  labs(y = "log-RSS") +
  labs(col = "Species") +
  scale_color_manual(values=c("#66C2A5", "#FC8D62", "#8DA0CB","#727D71")) + # or instead of the last one: #CF9963
  theme_light() +
  #scale_y_continuous(limits=c(-0.5, 2.6), breaks=c(0, 1, 2), labels=c("0", "1", "2")) +
  scale_x_continuous(breaks = c(1,2),
                     labels = c("Road Crossing 
:Night",
                                "Road Crossing 
:Twilight")
  ) +
  guides(colour=guide_legend(order=1), pch=guide_legend(order=2)) +
  theme_bw() +
  theme(axis.text.x = element_text(size = 16, vjust=0.7, face="bold"),
        axis.text.y = element_text(size = 18),
        axis.title.y = element_blank(),
        axis.title.x = element_blank(),
        plot.title = element_text(hjust = 0.5, size = 16, face = "bold",margin = margin(t = 0, r = 0, b = 15, l = 0)),
        legend.title = element_text(size = 14, face = "bold"),
        legend.text = element_text(size = 13, margin = margin(t = 0, r = 0, b = 5, l = 0)),
        panel.grid.major.x = element_blank(), panel.grid.minor.x = element_blank(), panel.grid.minor.y = element_blank(),
        panel.border = element_rect(linetype = "solid", fill=NA, linewidth=1))

rcross_tod

# get legend
rcross_leg <- as_ggplot(get_legend(rcross_tod +
                                  theme(legend.title = element_text(size=20, face="bold"),
                                        legend.title.align=0.5,
                                        legend.text = element_text(size = 18, margin = margin(t = 3)),
                                        legend.key.size=unit(0.8, "cm"), legend.key.width= unit(0.5, 'cm'),
                                        legend.direction = "vertical",
                                        legend.box = "horizontal",
                                        legend.spacing = unit(0.7, "cm"))))

rcross_leg

rcross_tod_leg <- 
  annotate_figure(ggarrange(plotlist = list(NULL, rcross_tod + theme(legend.position="null"), rcross_leg),
                            ncol = 3, nrow = 1, common.legend = F, widths = c(0.04, 1, 0.7)),
                  left = text_grob("log-RSS", rot = 90, size = 20, vjust=0.5, face="bold"))
rcross_tod_leg



##### Fig. 5a/5b ####

fig_5 <-
  annotate_figure(ggarrange(plotlist = list(dist_road_tod_p_all, NULL, rcross_tod_leg),
                            ncol = 1, nrow = 3, common.legend = F, heights = c(1, 0.07, 0.3),
                            labels=c("(a)", "", "(b)"), font.label=list(size=25), vjust = c(1, 1)))
fig_5

# ggsave(filename="fig_5.tiff", plot=fig_5, device="tiff", 
#        width=25, heigh=40, units="cm", dpi=300,
#        path=data_path, bg="white")
