#### Manuscript: OIK-10433
#### Title: Risk response towards roads is consistent across multiple species
##          in a temperate forest ecosystem
#### Date (creation): 12/2023
#### Date (last update): 01/2024
#### Purpose: Create caterpillar plots to investigate interindividual variability (Supporting information 5)


#### Load packages ####
library(dplyr)
library(glmmTMB)
library(ggplot2)
library(ggpubr)
library(purrr)
library(sjPlot)


#### Load functions ####

#### Function to create caterpillar plots
CatPlot <- function(model, term, plot=TRUE) {
  
  re <- ranef(model, condVar=TRUE)
  re_df <- re %>% as.data.frame() %>% filter(grpvar=="id")
  
  re_df <- re_df %>% mutate(category = ifelse(condval-condsd>0, "Higher",
                                              ifelse(condval+condsd<0, "Lower", "Median")) %>% 
                              factor(levels=c("Higher", "Median", "Lower")))
  
  re_df <- re_df %>% mutate(data = ifelse(model$call$data=="roetrk_ssf_f", "Roe deer females",
                                          ifelse(model$call$data=="roetrk_ssf_m", "Roe deer males",
                                                 ifelse(model$call$data=="redtrk_ssf_f", "Red deer females",
                                                        ifelse(model$call$data=="redtrk_ssf_m", "Red deer males",
                                                               ifelse(model$call$data=="boartrk_ssf_f", "Wild boar females",
                                                                      ifelse(model$call$data=="boartrk_ssf_m", "Wild boar males",
                                                                             ifelse(model$call$data=="lynxtrk_ssf", "Lynx", NA))))))))
  
  if(plot==FALSE) { return(re_df) } else
  
  if (term=="log_dist_road_end"){
    
    plot <-  re_df %>% filter(term=="log_dist_road_end") %>% mutate(grp = as.factor(grp)) %>% 
      ggplot(aes(x=condval, y=reorder(grp, condval), colour=category)) +
      geom_errorbar(aes(xmin = condval-condsd, xmax = condval+condsd), width=0, linewidth=1, colour="#636363") +
      geom_point(size = 4) +
      scale_color_manual(values = c("Higher" = "#1b9e77",
                                    "Median"="#7570b3" ,
                                    "Lower"="#d95f02")) +
      geom_vline(xintercept=0, linetype=2) +
      labs(y="Animal ID", x="Distance to road (ln)") +
      theme_bw() +
      theme(text = element_text(size=14),
            legend.position = "none")
    
  } else if (term=="crossings" & model$call$data!="boartrk_ssf_f"){
    
    plot <- re_df %>% filter(term=="crossings") %>% mutate(grp = as.factor(grp)) %>% 
      ggplot(aes(x=condval, y=reorder(grp, condval), colour=category)) +
      geom_errorbar(aes(xmin = condval-condsd, xmax = condval+condsd), width=0, linewidth=1, colour="#636363") +
      geom_point(size = 4) +
      scale_color_manual(values = c("Higher" = "#1b9e77",
                                    "Median"="#7570b3" ,
                                    "Lower"="#d95f02")) +
      geom_vline(xintercept=0, linetype=2) +
      labs(x="Road Crossing") +
      theme_bw() +
      theme(text = element_text(size=14), 
            axis.title.y = element_blank(),
            legend.position = "none")
    
  } else if (term=="crossings" & model$call$data=="boartrk_ssf_f") {
    return(plot) 
    
  }
  
}


#### Load Data ####

data_path <- " " #add the path to your data (e.g. "C:/Users/username/Downloads/")

## Load models
lynxmodel_1h <- readRDS(paste0(data_path, "model_lynx_1h.rds"))
boarfemalemodel <- readRDS(paste0(data_path, "model_boar_female.rds"))
boarmalemodel <- readRDS(paste0(data_path, "model_boar_male.rds"))
roefemalemodel <- readRDS(paste0(data_path, "model_roe_female.rds"))
roemalemodel <- readRDS(paste0(data_path, "model_roe_male.rds"))
redfemalemodel <- readRDS(paste0(data_path, "model_red_female.rds"))
redmalemodel <- readRDS(paste0(data_path, "model_red_male.rds"))
## Create model list
model_ls <- list(roemalemodel=roemalemodel, roefemalemodel=roefemalemodel,
                 redmalemodel=redmalemodel, redfemalemodel=redfemalemodel,
                 boarmalemodel=boarmalemodel, boarfemalemodel=boarfemalemodel,
                 lynxmodel_1h=lynxmodel_1h)


#### Supporting information 6 ####


##### Figures S9-S12 ####

catplots_dist <- map(model_ls, function(x) CatPlot(x, term="log_dist_road_end"))
catplots_dist

catplots_cross <- map(model_ls, function(x) CatPlot(x, term="crossings"))
catplots_cross


## Arrange plots
catplots_roe <- ggarrange(annotate_figure(ggarrange(plotlist=c(catplots_dist[2], catplots_cross[2])),
                                          top=text_grob("Roe deer females", size=16)),
                          annotate_figure(ggarrange(plotlist=c(catplots_dist[1], catplots_cross[1])),
                                          top=text_grob("Roe deer males", size=16)), nrow=2)

catplots_red <- ggarrange(annotate_figure(ggarrange(plotlist=c(catplots_dist[4], catplots_cross[4])),
                                          top=text_grob("Red deer females", size=16)),
                          annotate_figure(ggarrange(plotlist=c(catplots_dist[3], catplots_cross[3])),
                                          top=text_grob("Red deer males", size=16)), nrow=2)

catplots_boar <- ggarrange(annotate_figure(ggarrange(plotlist=c(catplots_dist[6], catplots_cross[6])), 
                                          top=text_grob("Wild boar females", size=16)),
                          annotate_figure(ggarrange(plotlist=c(catplots_dist[5], catplots_cross[5])),
                                          top=text_grob("Wild boar males", size=16)), nrow=2)
# Warning message:
# Package `gridGraphics` is required to handle base-R plots. Substituting empty plot.
## --> the plot is missing for wild boar females because road crossings is not in the model
# 1 fix per hour
catplots_lynx <- ggarrange(annotate_figure(ggarrange(plotlist=c(catplots_dist[7], catplots_cross[7])),
                                           top=text_grob("Lynx", size=16)), nrow=2)

catplots_ls <- list(roe=catplots_roe, red=catplots_red,
                    boar=catplots_boar, lynx=catplots_lynx)

## save plots
# for(i in 1:length(catplots_ls)) {
#   ggsave(filename=paste0("catplots_", names(catplots_ls[i]), ".tiff"),
#          plot=catplots_ls[[i]], device="tiff",
#          width=40, heigh=40,
#          units="cm", dpi=500,
#          path=data_path, bg="white")
# }


##### Table S3 ####

## Show actual values and percentages

## List of random effect dataframes
runef_ls <- map(model_ls, function(x) CatPlot(x, plot=FALSE))

## For each species and sex, calculate the percentage of each category (higher, median, lower) for the variable distance to roads and road crossings
perc_ls <- map(runef_ls, function(x)
  x %>% group_by(term, category) %>% 
  summarize(n = n()) %>% 
  mutate(prop = n / sum(n), label = paste0(round(prop * 100, 1), "%", " (", n, ")")) %>% 
    select(term, category, label))
perc_ls
perc_df <- bind_rows(perc_ls, .id="data")
View(perc_df)

## Create tidy table
tab_df(
  data.frame(perc_ls$roefemalemodel,
             perc_ls$roemalemodel[,c("label")],
             perc_ls$redfemalemodel[,c("label")],
             perc_ls$redmalemodel[,c("label")],
             rbind(perc_ls$boarfemalemodel[,c("label")], "-", "-", "-"),
             perc_ls$boarmalemodel[,c("label")],
             rbind("-", "100% (8)", "-", "-", "100% (8)", "-")),
  col.header = c("Term", "Category", "Females", "Males", "Females", "Males", "Females", "Males", "Lynx"),
  file = paste0(data_path, "perc_table.doc")
  )
